@@ -6,7 +6,7 @@
 # It defines a shell function for each known target
 # and then does a case to call the correct function.
 
-XINE_ACLOCALFLAGS="`xine-config --acflags`"
+unset MAKEFLAGS
 
 call_and_fix_autoconf()
 {
@@ -44,7 +44,7 @@ case $AUTOCONF_VERSION in
     exit 1
     ;;
 esac
- 
+
 AUTOHEADER_VERSION=`$AUTOHEADER --version | head -n 1`
 case $AUTOHEADER_VERSION in
   Autoconf*2.5* | autoheader*2.5* ) : ;;
@@ -68,15 +68,19 @@ case $AUTOMAKE_STRING in
     echo "*** KDE requires automake $required_automake_version"
     exit 1
     ;;
-  automake*1.6.* | automake*1.7* | automake*1.8* | automake*1.9*) : ;;
+  automake*1.6.* | automake*1.7* | automake*1.8* | automake*1.9*)
+    echo "*** $AUTOMAKE_STRING found."
+    UNSERMAKE=no
+    ;;
   "" )
     echo "*** AUTOMAKE NOT FOUND!."
     echo "*** KDE requires automake $required_automake_version"
     exit 1
     ;;
-  unsermake* ) :
+  *unsermake* ) :
     echo "*** YOU'RE USING UNSERMAKE."
     echo "*** GOOD LUCK!! :)"
+    UNSERMAKE=unsermake
     ;;
   * )
     echo "*** YOU'RE USING $AUTOMAKE_STRING."
@@ -90,7 +94,7 @@ unset required_automake_version
 cvs()
 {
 check_autotool_versions
-acinclude_m4 
+acinclude_m4
 
 ### Make new subdirs and configure.in.
 ### The make calls could be optimized away here,
@@ -102,7 +106,7 @@ if test -r configure.in.in; then
 
     if test -r Makefile.am.in; then
         echo "*** Creating Makefile.am"
-        if grep '\$(top_srcdir)/Makefile.am:' $makefile_am >/dev/null; then 
+        if grep '\$(top_srcdir)/Makefile.am:' $makefile_am >/dev/null; then
             strip_makefile
             $MAKE -f $makefile_wo top_srcdir=. ./Makefile.am || exit 1
         else
@@ -111,7 +115,7 @@ if test -r configure.in.in; then
      fi
      configure_files
      echo "*** Creating configure.in"
-     if grep '\$(top_srcdir)/configure.in:' $makefile_am >/dev/null; then 
+     if grep '\$(top_srcdir)/configure.in:' $makefile_am >/dev/null; then
        strip_makefile
        $MAKE -f $makefile_wo top_srcdir=. ./configure.in || exit 1
      else
@@ -131,7 +135,8 @@ fi
 
 echo "*** Creating Makefile templates"
 $AUTOMAKE || exit 1
-if test -z "$UNSERMAKE"; then
+
+if test "$UNSERMAKE" = no; then
   echo "*** Postprocessing Makefile templates"
   perl -w admin/am_edit || exit 1
 fi
@@ -162,7 +167,7 @@ if test -r configure.in.in; then
   create_subdirs
 
   if test -r Makefile.am.in; then
-    if grep '\$(top_srcdir)/Makefile.am:' $makefile_am >/dev/null; then 
+    if grep '\$(top_srcdir)/Makefile.am:' $makefile_am >/dev/null; then
       strip_makefile
       $MAKE -f $makefile_wo top_srcdir=. ./Makefile.am || exit 1
     else
@@ -170,7 +175,7 @@ if test -r configure.in.in; then
     fi
   fi
   configure_files
-  if grep '\$(top_srcdir)/configure.in:' $makefile_am >/dev/null; then 
+  if grep '\$(top_srcdir)/configure.in:' $makefile_am >/dev/null; then
     strip_makefile
     $MAKE -f $makefile_wo top_srcdir=. ./configure.in || exit 1
   else
@@ -182,8 +187,11 @@ if egrep "^AM_CONFIG_HEADER" configure.in >/dev/null 2>&1; then
   echo "*** Creating config.h template"
   $AUTOHEADER || exit 1
 fi
-$AUTOMAKE --foreign
-perl -w admin/am_edit
+$AUTOMAKE --foreign || exit 1
+if test "$UNSERMAKE" = no; then
+  echo "*** Postprocessing Makefile templates"
+  perl -w admin/am_edit || exit 1
+fi
 call_and_fix_autoconf
 touch stamp-h.in
 if grep "^cvs-local:" $makefile_am >/dev/null; then
@@ -212,7 +220,13 @@ subdir_dist()
 $ACLOCAL $ACLOCALFLAGS $XINE_ACLOCALFLAGS
 $AUTOHEADER
 $AUTOMAKE
-perl -w ../admin/am_edit --path=../admin
+AUTOMAKE_STRING=`$AUTOMAKE --version | head -n 1`
+case $AUTOMAKE_STRING in
+  *unsermake* ) :
+    ;;
+  *)
+     perl -w ../admin/am_edit --path=../admin
+esac
 call_and_fix_autoconf
 touch stamp-h.in
 }
@@ -224,7 +238,7 @@ kde_use_qt_param=
 test -f configure.files || { echo "need configure.files for configure.in"; exit 1; }
 list=`fgrep -v "configure.in.bot" < configure.files | fgrep -v "configure.in.mid"`
 : > configure.in.new
-for file in $list; do 
+for file in $list; do
   echo "dnl =======================================================" >> configure.in.new
   echo "dnl FILE: $file" >> configure.in.new
   echo "dnl =======================================================" >> configure.in.new
@@ -246,10 +260,6 @@ if test -f Makefile.am.in; then
 fi
 
 echo "AC_CONFIG_FILES([ Makefile ])" >> configure.in.new
-if test -n "$UNSERMAKE"; then
-  echo "AC_CONFIG_FILES([ Makefile.rules ])" >> configure.in.new
-  echo "AC_CONFIG_FILES([ Makefile.calls ])" >> configure.in.new
-fi
 
 if test -f inst-apps; then
     topleveldirs=`cat inst-apps`
@@ -262,7 +272,7 @@ else
     done
 fi
 
-for topleveldir in $topleveldirs; do 
+for topleveldir in $topleveldirs; do
   if test -f $topleveldir/configure.in; then
 	continue
   fi
@@ -274,23 +284,15 @@ for topleveldir in $topleveldirs; do
        sed -e 's#\./##; s#/Makefile.am$##' | sort | sed -e 's#$#/Makefile#'`
   for i in $mfs; do
      echo "AC_CONFIG_FILES([ $i ])" >> configure.in.new
-     if test -n "$UNSERMAKE"; then
-        echo "AC_CONFIG_FILES([ $i.rules ])" >> configure.in.new
-	echo "AC_CONFIG_FILES([ $i.calls ])" >> configure.in.new
-     fi
   done
 done
 
 files=`cat configure.files`
 list=`egrep '^dnl AC_OUTPUT\(.*\)' $files | sed -e "s#^.*dnl AC_OUTPUT(\(.*\))#\1#"`
-for file in $list; do 
+for file in $list; do
     echo "AC_CONFIG_FILES([ $file ])" >>  configure.in.new
 done
 
-if test -n "$UNSERMAKE"; then
-  echo "AC_CONFIG_FILES([ MakeVars ])" >> configure.in.new
-fi
-
 midfiles=`cat configure.files | fgrep "configure.in.mid"`
 test -n "$midfiles" && cat $midfiles >> configure.in.new
 
@@ -311,13 +313,13 @@ if test -f configure.in.in; then
    fi
 fi
 if test -z "$VERSION" || test "$VERSION" = "@VERSION@"; then
-     VERSION="\"3.3.0\""
+     VERSION="\"3.4.2\""
 fi
 if test -z "$modulename" || test "$modulename" = "@MODULENAME@"; then
-   modulename=`pwd`; 
+   modulename=`pwd`;
    modulename=`basename $modulename`
    esc_VERSION=`echo $VERSION | sed -e "s#[^.0-9a-zA-Z]##g"`
-   modulename=`echo $modulename | sed -e "s#-$esc_VERSION##"`   
+   modulename=`echo $modulename | sed -e "s#-$esc_VERSION##"`
 
 fi
 if test -n "$kde_use_qt_param"; then
@@ -370,7 +372,7 @@ fi
 
 create_subdirs()
 {
-if grep '\$(top_srcdir)/subdirs:' $makefile_am >/dev/null; then 
+if grep '\$(top_srcdir)/subdirs:' $makefile_am >/dev/null; then
     # as many modules contain rules to create subdirs without any
     # dependencies make won't create it unless there is no file.
     # so we check if that's a dummy rule or one that works
@@ -382,7 +384,7 @@ if grep '\$(top_srcdir)/subdirs:' $makefile_am >/dev/null; then
     $MAKE -f $makefile_wo top_srcdir=. ./subdirs || exit 1
     if test -f subdirs.cvs.sh.$$; then
 	if test -s subdirs; then
-	    rm subdirs.cvs.sh.$$ 
+	    rm subdirs.cvs.sh.$$
 	else
 	    mv subdirs.cvs.sh.$$ subdirs
 	fi
@@ -419,7 +421,7 @@ for d in $compilefirst; do
    echo $d >> ./_SUBDIRS
 done
 
-(for d in $dirs; do 
+(for d in $dirs; do
    list=`sed -ne "s#^COMPILE_BEFORE_$d""[ ]*=[ ]*##p" $makefile_am | head -n 1`
    for s in $list; do
       echo $s $d
@@ -466,7 +468,7 @@ if test -f Makefile.am.in; then
     adds=`ls -d -1 $adds 2>/dev/null`
     fgrep -v  '$(top_srcdir)/acinclude.m4:' Makefile.am.in > Makefile.am.in.adds
     str='$(top_srcdir)/acinclude.m4:'
-    for add in $adds; do 
+    for add in $adds; do
 	str="$str \$(top_srcdir)/$add"
     done
     echo $str >> Makefile.am.in.adds
@@ -474,23 +476,10 @@ if test -f Makefile.am.in; then
     cat Makefile.am.in > Makefile.am.in.adds
   fi
 
-  if test -n "$UNSERMAKE"; then
-    cat Makefile.am.in.adds > Makefile.am
-    topsubdirs=
-    for i in $compilefirst $dirs $compilelast; do
-       vari=`echo $i | sed -e "s,[-+],_,g"`
-       echo "if $vari""_SUBDIR_included" >> Makefile.am
-       echo "$vari""_SUBDIR=$i" >> Makefile.am
-       echo "endif" >> Makefile.am
-       topsubdirs="$topsubdirs \$($vari""_SUBDIR)"
-    done
-    echo "SUBDIRS=$topsubdirs" >> Makefile.am
-  else
-    cat Makefile.am.in.adds | \
-        sed -e 's,^\s*\(COMPILE_BEFORE.*\),# \1,' | \
-        sed -e 's,^\s*\(COMPILE_AFTER.*\),# \1,' > Makefile.am
+  cat Makefile.am.in.adds | \
+      sed -e 's,^\s*\(COMPILE_BEFORE.*\),# \1,' | \
+      sed -e 's,^\s*\(COMPILE_AFTER.*\),# \1,' > Makefile.am
     echo "SUBDIRS="'$(TOPSUBDIRS)' >> Makefile.am
-  fi
   rm Makefile.am.in.adds
 fi
 }
@@ -499,7 +488,7 @@ acinclude_m4()
 {
   echo "*** Creating acinclude.m4"
   adds=
-  if grep '\$(top_srcdir)/acinclude.m4:' $makefile_am >/dev/null; then 
+  if grep '\$(top_srcdir)/acinclude.m4:' $makefile_am >/dev/null; then
     strip_makefile
     rm -f acinclude.m4
     adds=`grep '\$(top_srcdir)/acinclude.m4:' $makefile_wo | sed -e 's,^[^:]*: *,,; s,\$(top_srcdir),.,g'`
@@ -513,7 +502,7 @@ acinclude_m4()
   fi
   # if it wasn't created up to now, then we do it better
   if test ! -f acinclude.m4; then
-     cat admin/acinclude.m4.in admin/libtool.m4.in $adds > acinclude.m4
+     cat admin/acinclude.m4.in admin/libtool.m4.in admin/pkg.m4.in $adds > acinclude.m4
   fi
 }
 
@@ -546,18 +535,8 @@ for cat in $catalogs; do
 done
 }
 
-package_messages()
+extract_messages()
 {
-rm -rf po.backup
-mkdir po.backup
-
-for i in `ls -1 po/*.pot 2>/dev/null | sed -e "s#po/##"`; do
-  egrep -v '^#([^:]|$)' po/$i | egrep '^.*[^ ]+.*$' | grep -v "\"POT-Creation" > po.backup/$i
-  cat po/$i > po.backup/backup_$i
-  touch -r po/$i po.backup/backup_$i
-  rm po/$i
-done
-
 podir=${podir:-$PWD/po}
 files=`find . -name Makefile.am | xargs egrep -l '^messages:' `
 dirs=`for i in $files; do echo \`dirname $i\`; done`
@@ -577,16 +556,16 @@ for subdir in $dirs; do
 	    echo "$subdir has *.rc, *.ui or *.kcfg files, but not correct messages line"
 	fi
    fi
-   if test -n "`find . -name \*.c\* -o -name \*.h\* | xargs grep -s KAboutData 2>/dev/null`"; then
+   if find . -name \*.c\* -o -name \*.h\* | fgrep -v ".svn" | xargs fgrep -s -q KAboutData ; then
 	echo -e 'i18n("_: NAME OF TRANSLATORS\\n"\n"Your names")\ni18n("_: EMAIL OF TRANSLATORS\\n"\n"Your emails")' > _translatorinfo.cpp
    else echo " " > _translatorinfo.cpp
    fi
    perl -e '$mes=0; while (<STDIN>) { next if (/^(if\s|else\s|endif)/); if (/^messages:/) { $mes=1; print $_; next; } if ($mes) { if (/$\\(XGETTEXT\)/ && / -o/) { s/ -o \$\(podir\)/ _translatorinfo.cpp -o \$\(podir\)/ } print $_; } else { print $_; } }' < Makefile.am | egrep -v '^include ' > _transMakefile
 
-   kdepotpath=${includedir:-${KDEDIR:-`kde-config --prefix`}/include}/kde.pot
+   kdepotpath=${includedir:-`kde-config --expandvars --install include`}/kde.pot
 
-   $MAKE -s -f _transMakefile podir=$podir EXTRACTRC="$EXTRACTRC" PREPARETIPS="$PREPARETIPS" \
-	XGETTEXT="${XGETTEXT:-xgettext} -C -ki18n -ktr2i18n -kI18N_NOOP -kaliasLocale -x $kdepotpath" messages 
+   $MAKE -s -f _transMakefile podir=$podir EXTRACTRC="$EXTRACTRC" PREPARETIPS="$PREPARETIPS" srcdir=. \
+	XGETTEXT="${XGETTEXT:-xgettext} --foreign-user -C -ci18n -ki18n -ktr2i18n -kI18N_NOOP -kI18N_NOOP2 -kaliasLocale -x $kdepotpath" messages
    exit_code=$?
    if test "$exit_code" != 0; then
        echo "make exit code: $exit_code"
@@ -598,18 +577,31 @@ for subdir in $dirs; do
    rm -f $subdir/_transMakefile
 done
 rm -f $tmpname
+}
+
+package_messages()
+{
+rm -rf po.backup
+mkdir po.backup
+
+for i in `ls -1 po/*.pot 2>/dev/null | sed -e "s#po/##"`; do
+  egrep -v '^#([^:]|$)' po/$i | egrep '^.*[^ ]+.*$' | grep -v "\"POT-Creation" > po.backup/$i
+  cat po/$i > po.backup/backup_$i
+  touch -r po/$i po.backup/backup_$i
+  rm po/$i
+done
+
+extract_messages
+
 for i in `ls -1 po.backup/*.pot 2>/dev/null | sed -e "s#po.backup/##" | egrep -v '^backup_'`; do
   test -f po/$i || echo "disappeared: $i"
 done
 for i in `ls -1 po/*.pot 2>/dev/null | sed -e "s#po/##"`; do
    sed -e 's,^"Content-Type: text/plain; charset=CHARSET\\n"$,"Content-Type: text/plain; charset=UTF-8\\n",' po/$i > po/$i.new && mv po/$i.new po/$i
-   msgmerge -q -o po/$i po/$i po/$i
+   #msgmerge -q -o po/$i po/$i po/$i
    egrep -v '^#([^:]|$)' po/$i | egrep '^.*[^ ]+.*$' | grep -v "\"POT-Creation" > temp.pot
-  if test -f po.backup/$i && test -n "`diff temp.pot po.backup/$i`"; then
+  if test -f po.backup/$i && ! cmp -s temp.pot po.backup/$i; then
 	echo "will update $i"
-        sed -e 's,^"Content-Type: text/plain; charset=CHARSET\\n"$,"Content-Type: text/plain; charset=UTF-8\\n",' po.backup/backup_$i > po/$i.new && mv po/$i.new po.backup/backup_$i
-	msgmerge -q po.backup/backup_$i po/$i > temp.pot
-	mv temp.pot po/$i
   else
     if test -f po.backup/backup_$i; then
       test -z "$VERBOSE" || echo "I'm restoring $i"
@@ -649,10 +641,10 @@ fi
 ### Main
 ###
 
-arg=`echo $1 | tr '\-.' __`
+arg=`echo $1 | tr .- __`
 case $arg in
   cvs | dist | subdir_dist | configure_in | configure_files | subdirs | \
-  cvs_clean | package_merge | package_messages | Makefile_am | acinclude_m4 ) $arg ;;
+  cvs_clean | package_merge | package_messages | Makefile_am | acinclude_m4 | extract_messages ) $arg ;;
   configure ) call_and_fix_autoconf ;;
   * ) echo "Usage: cvs.sh <target>"
       echo "Target can be one of:"
