@@ -4,7 +4,7 @@
     begin                : Wed Apr 21 2004
     copyright            : (C) 2004-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/08/06 23:28:07 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -187,7 +187,8 @@ void DVBconfig::setDownloadResult( Job *job )
 
 void DVBconfig::setDownloadPercent( Job *job, unsigned long percent )
 {
-	if ( downProgress && job ) downProgress->progressBar()->setProgress( percent );
+	if ( downProgress && job )
+		downProgress->progressBar()->setProgress( percent );
 }
 
 
@@ -217,7 +218,8 @@ bool DVBconfig::loadDvbData( QWidget *parent )
 		tar.directory()->copyTo( dvbConfigDir );
 		return true;
 	}
-	else return false;
+	else
+		return false;
 }
 
 
@@ -230,7 +232,8 @@ bool DVBconfig::localData()
 		tar.directory()->copyTo( dvbConfigDir );
 		return true;
 	}
-	else return false;
+	else
+		return false;
 }
 
 
@@ -240,7 +243,8 @@ bool DVBconfig::haveData()
 	if ( !QDir( dvbConfigDir+"dvb-s" ).exists() || !QDir( dvbConfigDir+"dvb-c" ).exists() || !QDir( dvbConfigDir+"dvb-t" ).exists() ) {
 		loadDvbData(0);
 		if ( !QDir( dvbConfigDir+"dvb-s" ).exists() || !QDir( dvbConfigDir+"dvb-c" ).exists() || !QDir( dvbConfigDir+"dvb-t" ).exists() ) {
-			if ( !localData() ) return false;
+			if ( !localData() )
+				return false;
 		}
 	}
 	return true;
@@ -290,9 +294,12 @@ void DVBconfig::changeIconCategory( const QString &name, const QString &icon )
 {
 	int i;
 
-	if ( name==i18n("All") ) allIcon = icon;
-	else if ( name==i18n("TV") ) tvIcon = icon;
-	else if ( name==i18n("Radio") ) radioIcon = icon;
+	if ( name==i18n("All") )
+		allIcon = icon;
+	else if ( name==i18n("TV") )
+		tvIcon = icon;
+	else if ( name==i18n("Radio") )
+		radioIcon = icon;
 	else {
 		for ( i=0; i<(int)categories.count(); i++ ) {
 			if ( categories.at(i)->name==name ) {
@@ -326,9 +333,11 @@ void DVBconfig::readConfig()
 	instantDuration = config->readNumEntry( "InstantDuration", 120 );
 	format = config->readNumEntry( "PrefFormat", OutTS );
 	recordDir = config->readEntry( "RecordDir", QDir::homeDirPath() );
-	if ( !recordDir.endsWith("/") ) recordDir+= "/";
+	if ( !recordDir.endsWith("/") )
+		recordDir+= "/";
 	shiftDir = config->readEntry( "ShiftDir", QDir::homeDirPath() );
-	if ( !shiftDir.endsWith("/") ) shiftDir+= "/";
+	if ( !shiftDir.endsWith("/") )
+		shiftDir+= "/";
 	for ( i=0; i<(int)devList.count(); i++ ) {
 		devList.at(i)->source = config->readEntry( QString("DVB%1").arg(i), "" );
 		if ( devList.at(i)->type==FE_QPSK ) {
@@ -347,7 +356,8 @@ void DVBconfig::readConfig()
 		}
 	}
 	j = config->readNumEntry( "NumCategories", 0 );
-	for ( i=0; i<j; i++ ) categories.append( new Category( config->readEntry( QString("CategoryName%1").arg(i), "" ), config->readEntry( QString("CategoryIcon%1").arg(i), "kaffeine" ) ) );
+	for ( i=0; i<j; i++ )
+		categories.append( new Category( config->readEntry( QString("CategoryName%1").arg(i), "" ), config->readEntry( QString("CategoryIcon%1").arg(i), "kaffeine" ) ) );
 	allIcon = config->readEntry( "AllIcon", "kaffeine" );
 	tvIcon = config->readEntry( "TvIcon", "kdvbtv" );
 	radioIcon = config->readEntry( "RadioIcon", "kdvbra" );
@@ -695,7 +705,8 @@ loop:
 		ret = KMessageBox::questionYesNo( this, i18n("<qt>Can't get DVB data from http://hftom.free.fr/kaxtv/dvbdata.tar.gz !<br>\
 			Check your internet connection, and say Yes to try again.<br>\
 			Or say No to cancel.<br> Should I try again ?</qt>") );
-		if ( ret==KMessageBox::Yes ) goto loop;
+		if ( ret==KMessageBox::Yes )
+			goto loop;
 		return;
 	}
 }
@@ -741,7 +752,8 @@ void DvbConfigDialog::satNumberChanged( int value, int devNum )
 void DvbConfigDialog::setRecordDir()
 {
 	QString s = KFileDialog::getExistingDirectory( recordDirLe->text().stripWhiteSpace() );
-	if ( !s.isEmpty() ) recordDirLe->setText( s );
+	if ( !s.isEmpty() )
+		recordDirLe->setText( s );
 }
 
 
@@ -749,7 +761,8 @@ void DvbConfigDialog::setRecordDir()
 void DvbConfigDialog::setShiftDir()
 {
 	QString s = KFileDialog::getExistingDirectory( shiftDirLe->text().stripWhiteSpace() );
-	if ( !s.isEmpty() ) shiftDirLe->setText( s );
+	if ( !s.isEmpty() )
+		shiftDirLe->setText( s );
 }
 
 
@@ -789,17 +802,21 @@ void DvbConfigDialog::accept()
 			if ( sat3[i]->isEnabled() ) s+="|"+sat3[i]->currentText();
 		}
 		else {
-			if ( dvbConfig->devList.at(i)->type==FE_QAM ) s = "C";
-			else s = "T";
+			if ( dvbConfig->devList.at(i)->type==FE_QAM )
+				s = "C";
+			else
+				s = "T";
 			s+="|"+sat0[i]->currentText();
 		}
 		dvbConfig->devList.at(i)->source = s;
 	}
 
 	dvbConfig->recordDir = recordDirLe->text();
-	if ( !dvbConfig->recordDir.endsWith("/") ) dvbConfig->recordDir+= "/";
+	if ( !dvbConfig->recordDir.endsWith("/") )
+		dvbConfig->recordDir+= "/";
 	dvbConfig->shiftDir = shiftDirLe->text();
-	if ( !dvbConfig->shiftDir.endsWith("/") ) dvbConfig->shiftDir+= "/";
+	if ( !dvbConfig->shiftDir.endsWith("/") )
+		dvbConfig->shiftDir+= "/";
 	dvbConfig->beginMargin = beginSpin->value();
 	dvbConfig->endMargin = endSpin->value();
 	dvbConfig->instantDuration = instantDurationSpin->value();
