@@ -4,7 +4,7 @@
     begin                : Tue Dec 16 2003
     copyright            : (C) 2003-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/07/31 19:04:48 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -57,7 +57,8 @@ DVBevents::~DVBevents()
 void DVBevents::doClean( bool b )
 {
 	if ( b ) {
-		if ( cleanTimer.isActive() ) return;
+		if ( cleanTimer.isActive() )
+			return;
 		cleanTimer.start( 3000 );
 	}
 	else {
@@ -74,13 +75,17 @@ bool DVBevents::shortEventDesc( unsigned char *buf, EventDesc *desc )
 	int len, len2;
 	ShortEvent *ev;
 
-	if ( !safeLen( buf+6 ) ) return false;
+	if ( !safeLen( buf+6 ) )
+		return false;
 	len = getBits(buf,40,8);
-	if ( !safeLen( buf+6+len ) ) return false;
+	if ( !safeLen( buf+6+len ) )
+		return false;
 	name = getText( buf+6, len );
-	if ( !safeLen( buf+6+len+1 ) ) return false;
+	if ( !safeLen( buf+6+len+1 ) )
+		return false;
 	len2 = getBits(buf+6+len,0,8);
-	if ( !safeLen( buf+7+len+len2 ) ) return false;
+	if ( !safeLen( buf+7+len+len2 ) )
+		return false;
 	text = getText( buf+7+len, len2);
 	if ( desc->title.isEmpty() ) {
 		desc->title=name;
@@ -102,27 +107,35 @@ bool DVBevents::extEventDesc( unsigned char *buf, EventDesc *desc )
 	unsigned char *b = buf;
 	QString s;
 
-	if ( !safeLen( b+7 ) ) return false;
+	if ( !safeLen( b+7 ) )
+		return false;
 	loop = getBits(b+6,0,8);
 	b +=7;
 
 	while ( loop>0 ) {
-		if ( !safeLen( b+1 ) ) return false;
+		if ( !safeLen( b+1 ) )
+			return false;
 		len1 = getBits(b,0,8);
-		if ( !safeLen( b+1+len1 ) ) return false;
+		if ( !safeLen( b+1+len1 ) )
+			return false;
 		s = getText(b+1,len1);
-		if ( !safeLen( b+1+len1+1 ) ) return false;
+		if ( !safeLen( b+1+len1+1 ) )
+			return false;
 		len2 = getBits(b+1+len1,0,8);
-		if ( !safeLen( buf+2+len1+len2 ) ) return false;
-		if ( !s.isEmpty() ) s = s+" : ";
+		if ( !safeLen( buf+2+len1+len2 ) )
+			return false;
+		if ( !s.isEmpty() )
+			s = s+" : ";
 		s = s+getText(b+2+len1,len2);
 		desc->extEvents.append( new QString( s ) );
 		b +=(2+len1+len2);
 		loop -=(2+len1+len2);
 	}
-	if ( !safeLen( b+1 ) ) return false;
+	if ( !safeLen( b+1 ) )
+		return false;
 	len1 = getBits(b,0,8);
-	if ( !safeLen( b+1+len1 ) ) return false;
+	if ( !safeLen( b+1+len1 ) )
+		return false;
 	s = getText(b+1,len1);
 	desc->extEvents.append( new QString( s ) );
 	return true;
@@ -151,9 +164,11 @@ bool DVBevents::tableEIT( unsigned char* buffer )
 
 	while ( length>4 ) {
 		nodesc=process=false;
-		if ( !safeLen( buf+2 ) ) goto stop;
+		if ( !safeLen( buf+2 ) )
+			goto stop;
 		eid = getBits(buf,0,16);
-		if ( !safeLen( buf+2+5 ) ) goto stop;
+		if ( !safeLen( buf+2+5 ) )
+			goto stop;
 		start = getDateTime( buf+2 );
 		nodesc=process=true;
 		it.toFirst();
@@ -176,11 +191,14 @@ bool DVBevents::tableEIT( unsigned char* buffer )
 			}
 			++it;
 		}
-		if ( nodesc ) desc = new EventDesc();
+		if ( nodesc )
+			desc = new EventDesc();
 		if ( process ) {
-			if ( !safeLen( buf+10 ) ) goto stop;
+			if ( !safeLen( buf+10 ) )
+				goto stop;
 			desc->duration = getTime( buf+7 );
-			if ( !safeLen( buf+11 ) ) goto stop;
+			if ( !safeLen( buf+11 ) )
+				goto stop;
 			desc->running = getBits(buf,80,3);
 			desc->sid = sid;
 			desc->tid = tid;
@@ -190,33 +208,40 @@ bool DVBevents::tableEIT( unsigned char* buffer )
 			desc->eid = eid;
 		}
 
-		if ( desc->sn != sn ) return false;
-		if ( !safeLen( buf+12 ) ) goto stop;
+		if ( desc->sn != sn )
+			return false;
+		if ( !safeLen( buf+12 ) )
+			goto stop;
 		loop = getBits(buf,84,12);
 		buf +=12;
 		length -=(12+loop);
 		while ( loop>0 ) {
 			if ( process ) {
-				if ( !safeLen( buf+1 ) ) goto out;
+				if ( !safeLen( buf+1 ) )
+					goto out;
 				switch ( getBits(buf,0,8) ) {
 					case 0x4D :
-						if ( !shortEventDesc( buf, desc ) ) goto out;
+						if ( !shortEventDesc( buf, desc ) )
+							goto out;
 						break;
 					case 0x4E :
-						if ( !extEventDesc( buf, desc ) ) goto out;
+						if ( !extEventDesc( buf, desc ) )
+							goto out;
 						break;
 					default :
 						break;
 				}
 			}
-			if ( !safeLen( buf+2 ) ) goto out;
+			if ( !safeLen( buf+2 ) )
+				goto out;
 			loop -=( getBits(buf,8,8)+2 );
 			buf +=( getBits(buf,8,8)+2 );
 		}
 out:
 		if ( process ) {
 			if ( !nodesc ) {
-				if ( start==desc->startDateTime ) goto ifend;
+				if ( start==desc->startDateTime )
+					goto ifend;
 				events.take( events.find( desc ) );
 			}
 			desc->startDateTime = start;
@@ -228,23 +253,29 @@ out:
 				}
 				itdesc = 0;
 			}
-			if ( !itdesc ) events.append( desc );
+			if ( !itdesc )
+				events.append( desc );
 		}
 ifend:
-		if ( process ) ++(desc->sn);
-		if ( desc->title.length()<3 ) events.remove( desc );
+		if ( process )
+			++(desc->sn);
+		if ( desc->title.length()<3 )
+			events.remove( desc );
 		else if ( nodesc ) {
 			cur = QDateTime::currentDateTime();
 			dt = desc->startDateTime;
 			sec = desc->duration.hour()*3600+desc->duration.minute()*60+desc->duration.second();
-			if ( dt.addSecs( sec )<cur ) events.remove( desc );
-			else desc->source = source;
+			if ( dt.addSecs( sec )<cur )
+				events.remove( desc );
+			else
+				desc->source = source;
 		}
 	}
 	return true;
 stop:
 	fprintf( stderr, "Stop parsing EIT\n" );
-	if ( nodesc ) delete desc;
+	if ( nodesc )
+		delete desc;
 	return false;
 }
 
@@ -252,7 +283,8 @@ stop:
 
 bool DVBevents::safeLen( unsigned char* buf )
 {
-	if ( !(buf>secbuf+4095) ) return true;
+	if ( !(buf>secbuf+4095) )
+		return true;
 	fprintf( stderr, "EIT : buffer overflow !! Rejected\n" );
 	return false;
 }
@@ -263,12 +295,16 @@ bool DVBevents::go( QString src, bool all )
 {
 	int tid;
 
-	if ( demuxOpened ) return true;
+	if ( demuxOpened )
+		return true;
 
-	if ( all ) tid = 0;
-	else tid = 0x4e;
+	if ( all )
+		tid = 0;
+	else
+		tid = 0x4e;
 	source = src;
-	if ( !setFilter( 0x12, tid, 1000 ) ) return false;
+	if ( !setFilter( 0x12, tid, 1000 ) )
+		return false;
 	demuxOpened = true;
 	fprintf(stderr,"dvbEvents started\n");
 	return true;
@@ -278,7 +314,8 @@ bool DVBevents::go( QString src, bool all )
 
 void DVBevents::stop()
 {
-	if ( !demuxOpened ) return;
+	if ( !demuxOpened )
+		return;
 
 	demuxOpened = false;
 	isRunning = false;
@@ -287,7 +324,8 @@ void DVBevents::stop()
 		wait();
 		fprintf(stderr,"dvbEvents terminated\n");
 	}
-	else fprintf(stderr,"dvbEvents ended\n");
+	else
+		fprintf(stderr,"dvbEvents ended\n");
 	stopFilter();
 	isRunning = true;
 	start();
@@ -317,7 +355,8 @@ void DVBevents::run()
 			while ( (itdesc = it.current())!=0 ) {
 				dt = itdesc->startDateTime;
 				sec = itdesc->duration.hour()*3600+itdesc->duration.minute()*60+itdesc->duration.second();
-				if ( dt.addSecs( sec )<cur ) events.remove( itdesc );
+				if ( dt.addSecs( sec )<cur )
+					events.remove( itdesc );
 				++it;
 			}
 			clean = false;
@@ -334,12 +373,16 @@ void DVBevents::run()
 				n = read( fdDemux, secbuf, 4096 );
 				skip = 0;
 			}
-			else skip++;
+			else
+				skip++;
 		}
-		else skip++;
+		else
+			skip++;
 
-		if (skip) continue;
-		if ( n<4 ) continue;
+		if (skip)
+			continue;
+		if ( n<4 )
+			continue;
 
 		switch ( getBits(secbuf,0,8) ) {
 			case 0x4E :
@@ -368,10 +411,13 @@ void DVBevents::dumpEvents()
 
 	stop();
 	it.toFirst();
-	if ( it.current() ) dt = it.current()->startDateTime;
+	if ( it.current() )
+		dt = it.current()->startDateTime;
 	while ( (desc = it.current())!=0 ) {
-		if ( desc->startDateTime<dt ) fprintf( stderr,"\nSORT ERROR !!\n");
-		else dt = desc->startDateTime;
+		if ( desc->startDateTime<dt )
+			fprintf( stderr,"\nSORT ERROR !!\n");
+		else
+			dt = desc->startDateTime;
 		fprintf(stderr,"%d %d %d  %s %s\n", desc->tsid, desc->sid, desc->eid, desc->startDateTime.toString().latin1(), desc->title.latin1() );
 		++it;
 	}
