@@ -4,7 +4,7 @@
     begin                : Mon Jan 19 2004
     copyright            : (C) 2004-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/08/06 23:28:07 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -56,8 +56,10 @@ void DIconViewItem::dropped( QDropEvent *e, const QValueList<QIconDragItem> & )
 {
 	QString s;
 
-	if ( !dropEnabled() ) return;
-	if ( QTextDrag::decode( e, s ) ) panel->moveChannel( text(), s );
+	if ( !dropEnabled() )
+		return;
+	if ( QTextDrag::decode( e, s ) )
+		panel->moveChannel( text(), s );
 }
 
 
@@ -70,10 +72,10 @@ DListView::DListView( QWidget *parent ) : KListView( parent )
 
 QDragObject* DListView::dragObject()
 {
-	if ( currentItem() ) {
+	if ( currentItem() )
 		return new QTextDrag( currentItem()->text(1), this );
-	}
-	else return 0;
+	else
+		return 0;
 }
 
 
@@ -230,10 +232,14 @@ void DvbPanel::catSelected( QIconViewItem *it )
 {
 	if ( !it ) return;
 
-	if ( it->text()==i18n("All") ) currentCategory = "All";
-	else if ( it->text()==i18n("TV") ) currentCategory = "TV";
-	else if ( it->text()==i18n("Radio") ) currentCategory = "Radio";
-	else currentCategory = it->text();
+	if ( it->text()==i18n("All") )
+		currentCategory = "All";
+	else if ( it->text()==i18n("TV") )
+		currentCategory = "TV";
+	else if ( it->text()==i18n("Radio") )
+		currentCategory = "Radio";
+	else
+		currentCategory = it->text();
 	fillChannelList();
 }
 
@@ -251,13 +257,17 @@ void DvbPanel::catContextMenu( QIconViewItem *it, const QPoint &p )
 	}
 	else {
 		pop->insertItem( i18n("Change icon ..."), 1 );
-		if ( it->text()!=i18n("All") && it->text()!=i18n("Radio") && it->text()!=i18n("TV") ) pop->insertItem( i18n("Delete category..."), 2 );
+		if ( it->text()!=i18n("All") && it->text()!=i18n("Radio") && it->text()!=i18n("TV") )
+			pop->insertItem( i18n("Delete category..."), 2 );
 	}
 	i = pop->exec( p );
 	switch ( i ) {
 		case 0 :
 			name = KInputDialog::getText( i18n("New category"), i18n("Enter a name for this category:"), "", &ok);
-			for ( QIconViewItem *qitem = iconView->firstItem(); qitem; qitem = qitem->nextItem() ) if ( qitem->text()==name ) ok = false;
+			for ( QIconViewItem *qitem = iconView->firstItem(); qitem; qitem = qitem->nextItem() ) {
+				if ( qitem->text()==name )
+					ok = false;
+			}
 			if ( ok ) {
 				KIconViewItem* item = item = new DIconViewItem(this, iconView, name, KGlobal::iconLoader()->loadIcon("kaffeine", KIcon::NoGroup, KIcon::SizeMedium));
 				item->setDropEnabled( true );
@@ -295,10 +305,13 @@ void DvbPanel::moveChannel( const QString &cat, const QString &name )
 	for ( i=0; i<(int)channels.count(); i++ ) {
 		chan = channels.at(i);
 		if ( chan->name==name ) {
-			if ( cat==i18n("All") ) chan->category = "";
-			else chan->category = cat;
+			if ( cat==i18n("All") )
+				chan->category = "";
+			else
+				chan->category = cat;
 			it = channelsCb->currentItem();
-			if ( it && currentCategory!="All" && currentCategory!="TV" && currentCategory!="Radio" ) delete it;
+			if ( it && currentCategory!="All" && currentCategory!="TV" && currentCategory!="Radio" )
+				delete it;
 			break;
 		}
 	}
@@ -375,11 +388,13 @@ void DvbPanel::dvbOSD()
 		}
 	}
 
-	if ( !d ) return;
+	if ( !d )
+		return;
 
 	events = d->dvbEvents;
 	ChannelDesc liveChannel = d->getLiveChannel();
-	if ( liveChannel.name.isEmpty() ) return;
+	if ( liveChannel.name.isEmpty() )
+		return;
 
 	if ( osdMode==2 ) {
 		osdTimer.stop();
@@ -389,20 +404,27 @@ void DvbPanel::dvbOSD()
 		return;
 	}
 
-	if ( osdMode==1 ) osdTimer.stop();
+	if ( osdMode==1 )
+		osdTimer.stop();
 
 	if ( osdMode==0 ) {
-		if ( d->liveIsRecording() ) list.append( "R" );
-		if ( d->timeShiftMode() ) list.append( "T" );
+		if ( d->liveIsRecording() )
+			list.append( "R" );
+		if ( d->timeShiftMode() )
+			list.append( "T" );
 	}
-	else list.append( "E" );
+	else
+		list.append( "E" );
 
 	k = 0;
 	for ( j=0; j<(int)events->events.count(); j++ ) {
 		desc = events->events.at(j);
-		if ( desc->tid>0x4f ) continue;
-		if ( desc->source!=liveChannel.tp.source || desc->sid!=liveChannel.sid || desc->tsid!=liveChannel.tp.tsid ) continue;
-		if ( desc->running!=4 && desc->running!=1 ) continue;
+		if ( desc->tid>0x4f )
+			continue;
+		if ( desc->source!=liveChannel.tp.source || desc->sid!=liveChannel.sid || desc->tsid!=liveChannel.tp.tsid )
+			continue;
+		if ( desc->running!=4 && desc->running!=1 )
+			continue;
 		if ( !desc->title.isEmpty() ) {
 			s = desc->startDateTime.toString( "hh:mm" );
 			s = s+" - ";
@@ -410,10 +432,13 @@ void DvbPanel::dvbOSD()
 			list.append( s );
 			k++;
 		}
-		else if ( osdMode ) list.append( "" );
+		else if ( osdMode )
+			list.append( "" );
 		if ( osdMode==0 ) {
-			if ( k>1 ) break;
-			else continue;
+			if ( k>1 )
+				break;
+			else
+				continue;
 		}
 		list.append( desc->subtitle );
 		s = "";
@@ -430,7 +455,8 @@ void DvbPanel::dvbOSD()
 		list.append( s );
 		break;
 	}
-	if ( osdMode==0 ) osdTimer.start( 5000, true );
+	if ( osdMode==0 )
+		osdTimer.start( 5000, true );
 	osdMode++;
 	emit showDvbOSD( list );
 }
@@ -446,7 +472,8 @@ void DvbPanel::enableLiveDvb( bool on )
 
 void DvbPanel::checkFirstRun()
 {
-	if ( dvbConfig->firstRun() ) showConfigDialog();
+	if ( dvbConfig->firstRun() )
+		showConfigDialog();
 }
 
 
@@ -484,7 +511,8 @@ void DvbPanel::setConfig()
 	}
 	fifoName = QDir::homeDirPath()+"/.kaxtv.ts";
 	QFile f( fifoName );
-	if ( f.exists() ) f.remove();
+	if ( f.exists() )
+		f.remove();
 	if ( (mkfifo( fifoName, 0644 ))<0 ) {
 		perror( fifoName.latin1() );
 		fifoName = "";
@@ -509,7 +537,8 @@ loop:
 			Check your internet connection, and say Yes to try again.<br>\
 			Or say No to cancel.<br>\
 			If you already have this archive, copy it to ~/.kde/share/apps/kaffeine/dvbdata.tar.gz and say Yes.<br><br>Should I try again ?</qt>") );
-		if ( ret==KMessageBox::Yes ) goto loop;
+		if ( ret==KMessageBox::Yes )
+			goto loop;
 		return;
 	}
 
@@ -517,7 +546,8 @@ loop:
 	connect( dlg.dumpBtn, SIGNAL(clicked()), this, SLOT(dumpEvents()) );
 	ret = dlg.exec();
 	disconnect( dlg.dumpBtn, SIGNAL(clicked()), this, SLOT(dumpEvents()) );
-	if ( ret==DvbConfigDialog::Rejected ) return;
+	if ( ret==DvbConfigDialog::Rejected )
+		return;
 	for ( i=0; i<(int)dvbConfig->devList.count(); i++ ) {
 		dvb.at(i)->setSources( dvbConfig->devList.at(i)->source );
 		dvb.at(i)->setLnb( 0, dvbConfig->devList.at(i)->lnb0 );
@@ -541,7 +571,8 @@ QPtrList<Transponder> DvbPanel::getSourcesStatus()
 	for ( i=0; i<(int)dvb.count(); i++ ) {
 		list = dvb.at(i)->getSources();
 		for ( j=0; j<(int)list.count(); j++ ) {
-			if ( dvb.at(i)->hasRec() || dvb.at(i)->hasBroadcast() ) t =  dvb.at(i)->getCurrentTransponder();
+			if ( dvb.at(i)->hasRec() || dvb.at(i)->hasBroadcast() )
+				t =  dvb.at(i)->getCurrentTransponder();
 			else {
 				t = Transponder();
 				t.source = list[j];
@@ -572,27 +603,36 @@ void DvbPanel::fillChannelList()
 				if ( trans.at(j)->freq ) {
 					if ( chan->tp==*trans.at(j) ) break;
 				}
-				else break;
+				else
+					break;
 			}
 			cont = true;
 		}
-		if ( cont ) continue;
+		if ( cont )
+			continue;
 		if ( currentCategory=="TV" ) {
-			if ( chan->type!=1 ) continue;
+			if ( chan->type!=1 )
+				continue;
 		}
 		else if ( currentCategory=="Radio" ) {
-			if ( chan->type!=2 ) continue;
+			if ( chan->type!=2 )
+				continue;
 		}
-		else if ( currentCategory!="All" && chan->category!=currentCategory ) continue;
+		else if ( currentCategory!="All" && chan->category!=currentCategory )
+			continue;
 		it = new KListViewItem( channelsCb, QString().sprintf("%04d", chan->num), chan->name );
 		it->setDragEnabled( true );
 		if ( chan->type==1 ) {
-			if ( chan->fta ) it->setPixmap( 1, tvcPix );
-			else it->setPixmap( 1, tvPix );
+			if ( chan->fta )
+				it->setPixmap( 1, tvcPix );
+			else
+				it->setPixmap( 1, tvPix );
 		}
 		else {
-			if ( chan->fta ) it->setPixmap( 1, racPix );
-			else it->setPixmap( 1, raPix );
+			if ( chan->fta )
+				it->setPixmap( 1, racPix );
+			else
+				it->setPixmap( 1, raPix );
 		}
 	}
 	trans.clear();
@@ -605,7 +645,8 @@ DvbStream* DvbPanel::getWorkingDvb( int mode, ChannelDesc *chan )
 	int i, ret;
 	QValueList<int> working; //  notTuned=0, hasLive=1, hasBroadcast=2, hasRec=3, can'tDoChannel=4
 
-	for ( i=0; i<(int)dvb.count(); i++ ) working.append( 0 );
+	for ( i=0; i<(int)dvb.count(); i++ )
+		working.append( 0 );
 
 	// fill in working status
 	for ( i=0; i<(int)dvb.count(); i++ ) {
@@ -617,11 +658,15 @@ DvbStream* DvbPanel::getWorkingDvb( int mode, ChannelDesc *chan )
 			if ( dvb.at(i)->getCurrentTransponder()==chan->tp ) {
 				return dvb.at(i); // use that one since it's already tuned on the good mplex
 			}
-			else if ( dvb.at(i)->hasRec() ) working[i] = 3;
-			else if ( dvb.at(i)->hasBroadcast() ) working[i] = 2;
-			else working[i] = 1;
+			else if ( dvb.at(i)->hasRec() )
+				working[i] = 3;
+			else if ( dvb.at(i)->hasBroadcast() )
+				working[i] = 2;
+			else
+				working[i] = 1;
 		}
-		else working[i] = 0;
+		else
+			working[i] = 0;
 	}
 	ret = 0;
 	// search for least working card
@@ -631,8 +676,10 @@ DvbStream* DvbPanel::getWorkingDvb( int mode, ChannelDesc *chan )
 			ret = i;
 		}
 	}
-	if ( working[0]<mode ) return dvb.at(ret);
-	else return 0;
+	if ( working[0]<mode )
+		return dvb.at(ret);
+	else
+		return 0;
 }
 
 
@@ -646,10 +693,12 @@ void DvbPanel::setBroadcast()
 
 	BroadcastEditor dlg( this, &channels, &list );
 	ret = dlg.exec();
-	if ( ret==BroadcastEditor::Rejected ) return;
+	if ( ret==BroadcastEditor::Rejected )
+		return;
 
 	for ( i=0; i<(int)dvb.count(); i++ ) {
-		if ( dvb.at(i)->hasBroadcast() ) dvb.at(i)->stopBroadcast();
+		if ( dvb.at(i)->hasBroadcast() )
+			dvb.at(i)->stopBroadcast();
 	}
 	if ( ! list.count() ) {
 		fillChannelList();
@@ -658,19 +707,22 @@ void DvbPanel::setBroadcast()
 
 	d = getWorkingDvb( 2, list.at(0) );
 
-	if ( d ) ret = d->canStartBroadcast( live, list.at(0) );
-	else ret = -1;
+	if ( d )
+		ret = d->canStartBroadcast( live, list.at(0) );
+	else
+		ret = -1;
 	if ( ret==0 ) {
 		if ( live ) {
 			stopLive();
 			emit dvbStop();
 		}
-		if ( !d->startBroadcast( &list, rtp ) ) KMessageBox::information( this, i18n("Broadcasting failed.") );
-		else {
+		if ( !d->startBroadcast( &list, rtp ) )
+			KMessageBox::information( this, i18n("Broadcasting failed.") );
+		else
 			fillChannelList();
-		}
 	}
-	else KMessageBox::information( this, i18n("Can't start broadcasting.") );
+	else
+		KMessageBox::information( this, i18n("Can't start broadcasting.") );
 }
 
 
@@ -686,7 +738,8 @@ void DvbPanel::checkTimers()
 
 	for ( i=0; i<(int)timers.count(); i++ ) {
 		t = timers.at(i);
-		if ( t->running ) continue;
+		if ( t->running )
+			continue;
 		if ( t->begin.date()==cur.date() && t->begin.time().hour()==cur.time().hour() && t->begin.time().minute()==cur.time().minute() ) {
 			chan = 0;
 			for ( j=0; j<(int)channels.count(); j++ ) {
@@ -695,11 +748,14 @@ void DvbPanel::checkTimers()
 					break;
 				}
 			}
-			if ( !chan ) continue;
+			if ( !chan )
+				continue;
 			d = getWorkingDvb( 3, chan );
 			live = false;
-			if ( d ) ret = d->canStartTimer( live, chan );
-			else ret = -1;
+			if ( d )
+				ret = d->canStartTimer( live, chan );
+			else
+				ret = -1;
 			if ( ret==0 ) {
 				if ( live ) {
 					stopLive();
@@ -707,19 +763,23 @@ void DvbPanel::checkTimers()
 				}
 				if ( d->startTimer( chan, dvbConfig->recordDir, t ) ) {
 					t->running = 1;
-					if ( timersDialog ) emit timersChanged();
+					if ( timersDialog )
+						emit timersChanged();
 					saveTimerList();
 					audioComb->setEnabled( false );
 					i--;
 				}
-				else fprintf( stderr, "start timer failed!!!\n" );
+				else
+					fprintf( stderr, "start timer failed!!!\n" );
 			}
-			else fprintf( stderr, "Cant start timer !!!\n" );
+			else
+				fprintf( stderr, "Cant start timer !!!\n" );
 		}
 		else if ( t->mode ) {
 			if (t->begin.addSecs(t->duration.hour()*3600+t->duration.minute()*60+60)<cur) {
 				updateModeTimer( t );
-				if ( timersDialog ) emit timersChanged();
+				if ( timersDialog )
+					emit timersChanged();
 			}
 		}
 	}
@@ -744,12 +804,15 @@ void DvbPanel::setRecord()
 			break;
 		}
 	}
-	if ( !d ) return;
+	if ( !d )
+		return;
 
 	for ( j=0; j<(int)d->dvbEvents->events.count(); j++ ) {
 		desc = d->dvbEvents->events.at(j);
-		if ( desc->sid!=curchan.sid || desc->tsid!=curchan.tp.tsid ) continue;
-		if ( desc->running!=4 ) continue;
+		if ( desc->sid!=curchan.sid || desc->tsid!=curchan.tp.tsid )
+			continue;
+		if ( desc->running!=4 )
+			continue;
 		s = desc->title;
 		break;
 	}
@@ -771,10 +834,12 @@ void DvbPanel::setRecord()
 		if ( d->startTimer( &curchan, dvbConfig->recordDir, rt ) ) {
 			for ( i=0; i<(int)timers.count(); i++ ) {
 				t = timers.at(i);
-				if ( rt->begin>t->begin ) r=i+1;
+				if ( rt->begin>t->begin )
+					r=i+1;
 			}
 			timers.insert( r, rt );
-			if ( timersDialog ) emit timersChanged();
+			if ( timersDialog )
+				emit timersChanged();
 			saveTimerList();
 			audioComb->setEnabled( false );
 			KMessageBox::information( this, i18n("Timer successfully created and started.") );
@@ -808,8 +873,10 @@ void DvbPanel::setRecordLed( bool on )
 				break;
 			}
 		}
-		if ( !rec ) recordLed->off();
-		else recordLed->on();
+		if ( !rec )
+			recordLed->off();
+		else
+			recordLed->on();
 		fillChannelList();
 	}
 }
@@ -828,7 +895,8 @@ void DvbPanel::playNumChannel( int num )
 		}
 	}
 
-	if ( ok ) dvbZap( channels.at( j ) );
+	if ( ok )
+		dvbZap( channels.at( j ) );
 }
 
 
@@ -839,9 +907,12 @@ void DvbPanel::killTimer( RecTimer *t )
 
 	for ( i=0; i<(int)timers.count(); i++ ) {
 		if ( timers.at(i)==t ) {
-			if ( t->mode ) updateModeTimer( t );
-			else timers.remove( t );
-			if ( timersDialog ) emit timersChanged();
+			if ( t->mode )
+				updateModeTimer( t );
+			else
+				timers.remove( t );
+			if ( timersDialog )
+				emit timersChanged();
 			return;
 		}
 	}
@@ -881,7 +952,8 @@ void DvbPanel::updateModeTimer( RecTimer *t )
 	timers.remove( t );
 	for ( i=0; i<(int)timers.count(); i++ ) {
 		t = timers.at(i);
-		if ( nt->begin>t->begin ) r=i+1;
+		if ( nt->begin>t->begin )
+			r=i+1;
 	}
 	timers.insert( r, nt );
 }
@@ -898,9 +970,12 @@ void DvbPanel::showTimers()
 		KMessageBox::sorry( 0, i18n("You may want to define some channel first !") );
 		return;
 	}
-	for ( i=0; i<(int)channels.count(); i++ ) map[channels.at(i)->name.upper()] = channels.at(i)->name;
+	for ( i=0; i<(int)channels.count(); i++ )
+		map[channels.at(i)->name.upper()] = channels.at(i)->name;
 	QMap<QString,QString>::Iterator it;
-        for ( it = map.begin(); it != map.end(); ++it ) list.append( it.data() );
+	QMap<QString,QString>::Iterator end(map.end());
+        for ( it = map.begin(); it != end; ++it )
+        	list.append( it.data() );
 
 	timersDialog = new KRecord( list, &timers, this, dvbConfig->timerSize, dvbConfig->format );
 	for ( i=0; i<(int)dvb.count(); i++ ) {
@@ -936,7 +1011,8 @@ void DvbPanel::newTimer( QString channel, QString name, QDateTime begin, QTime d
 
 	for ( i=0; i<(int)timers.count(); i++ ) {
 		t = timers.at(i);
-		if ( rt->begin>t->begin ) r=i+1;
+		if ( rt->begin>t->begin )
+			r=i+1;
 	}
 	timers.insert( r, rt );
 	KMessageBox::information( 0, i18n("Timer successfully created.") );
@@ -954,11 +1030,13 @@ loop:
 			Check your internet connection, and say Yes to try again.<br>\
 			Or say No to cancel.<br>\
 			If you already have this archive, copy it to ~/.kde/share/apps/kaffeine/dvbdata.tar.gz and say Yes.<br><br>Should I try again ?</qt>") );
-		if ( ret==KMessageBox::Yes ) goto loop;
+		if ( ret==KMessageBox::Yes )
+			goto loop;
 		return;
 	}
 
-	if ( !dvbConfig->haveData() ) return;
+	if ( !dvbConfig->haveData() )
+		return;
 	ScanDialog dlg( &dvb, &channels, dvbConfig->scanSize, dvbConfig->dvbConfigDir );
 	dlg.exec();
 	dvbConfig->scanSize = dlg.size();
@@ -972,7 +1050,8 @@ void DvbPanel::showEvents()
 {
 	int i;
 
-	for ( i=0; i<(int)dvb.count(); i++ ) dvb.at(i)->dvbEvents->doClean( false );
+	for ( i=0; i<(int)dvb.count(); i++ )
+		dvb.at(i)->dvbEvents->doClean( false );
 	KEvents dlg( &channels, &dvb, this, dvbConfig->epgSize );
 	connect( &dlg, SIGNAL(addTimer(QString,QString,QDateTime,QTime)), this, SLOT(newTimer(QString,QString,QDateTime,QTime)) );
 	connect( &dlg, SIGNAL(zapTo(const QString &)), this, SLOT(channelSelected(const QString &)) );
@@ -980,7 +1059,8 @@ void DvbPanel::showEvents()
 	dvbConfig->epgSize = dlg.size();
 	disconnect( &dlg, SIGNAL(addTimer(QString,QString,QDateTime,QTime)), this, SLOT(newTimer(QString,QString,QDateTime,QTime)) );
 	disconnect( &dlg, SIGNAL(zapTo(const QString &)), this, SLOT(channelSelected(const QString &)) );
-	for ( i=0; i<(int)dvb.count(); i++ ) dvb.at(i)->dvbEvents->doClean( true );
+	for ( i=0; i<(int)dvb.count(); i++ )
+		dvb.at(i)->dvbEvents->doClean( true );
 }
 
 
@@ -991,7 +1071,8 @@ void DvbPanel::setShiftLed( bool on )
 		shiftLed->on();
 		audioComb->setEnabled( false );
 	}
-	else shiftLed->off();
+	else
+		shiftLed->off();
 }
 
 
@@ -1041,7 +1122,8 @@ void DvbPanel::audioSelected( int n )
 			break;
 		}
 	}
-	if ( !d ) return;
+	if ( !d )
+		return;
 
 	ChannelDesc chan=d->getLiveChannel();
 	emit setTimeShiftFilename( "" );
@@ -1057,7 +1139,8 @@ void DvbPanel::playLastChannel()
 	int j;
 	bool ok=false;
 
-	if ( !channelsCb->isEnabled() ) return;
+	if ( !channelsCb->isEnabled() )
+		return;
 
 	for ( j=0; j<(int)channels.count(); j++ ) {
 		if ( (int)channels.at(j)->num==dvbConfig->lastChannel ) {
@@ -1065,7 +1148,8 @@ void DvbPanel::playLastChannel()
 			break;
 		}
 	}
-	if ( !ok ) return;
+	if ( !ok )
+		return;
 
 	dvbZap( channels.at(j) );
 }
@@ -1077,9 +1161,11 @@ void DvbPanel::next()
 	int j;
 	bool ok=false;
 
-	if ( !channelsCb->isEnabled() ) return;
+	if ( !channelsCb->isEnabled() )
+		return;
 
-	if ( dvbConfig->lastChannel>((int)channels.count()-1) ) return;
+	if ( dvbConfig->lastChannel>((int)channels.count()-1) )
+		return;
 
 	for ( j=0; j<(int)channels.count(); j++ ) {
 		if ( (int)channels.at(j)->num==(dvbConfig->lastChannel+1) ) {
@@ -1087,7 +1173,8 @@ void DvbPanel::next()
 			break;
 		}
 	}
-	if ( !ok ) return;
+	if ( !ok )
+		return;
 
 	dvbZap( channels.at(j) );
 }
@@ -1099,9 +1186,11 @@ void DvbPanel::previous()
 	int j;
 	bool ok=false;
 
-	if ( !channelsCb->isEnabled() ) return;
+	if ( !channelsCb->isEnabled() )
+		return;
 
-	if ( dvbConfig->lastChannel<2 ) return;
+	if ( dvbConfig->lastChannel<2 )
+		return;
 
 	for ( j=0; j<(int)channels.count(); j++ ) {
 		if ( (int)channels.at(j)->num==(dvbConfig->lastChannel-1) ) {
@@ -1109,7 +1198,8 @@ void DvbPanel::previous()
 			break;
 		}
 	}
-	if ( !ok ) return;
+	if ( !ok )
+		return;
 
 	dvbZap( channels.at(j) );
 }
@@ -1122,14 +1212,16 @@ void DvbPanel::dvbZap( ChannelDesc *chan )
 	int i;
 	DvbStream *d=0;
 
-	if ( fifoName.isEmpty() ) return;
+	if ( fifoName.isEmpty() )
+		return;
 
 	audioComb->setEnabled( false );
 	emit setTimeShiftFilename( "" );
 	for ( i=0; i<(int)dvb.count(); i++ ) {
 		if ( dvb.at(i)->hasLive() ) {
 			emit dvbPause( false );
-			if ( dvb.at(i)->getLiveChannel().tp==chan->tp ) d = dvb.at(i);
+			if ( dvb.at(i)->getLiveChannel().tp==chan->tp )
+				d = dvb.at(i);
 			dvb.at(i)->stopLive( chan );
 			break;
 		}
@@ -1153,7 +1245,8 @@ void DvbPanel::finalZap( DvbStream *d, ChannelDesc *chan, bool setAudio, int nap
 	tm.start();
 	if ( !d1 ) {
 		for ( i=0; i<(int)dvb.count(); i++ ) {
-			if ( !dvb.at(i)->canSource( chan ) ) continue;
+			if ( !dvb.at(i)->canSource( chan ) )
+				continue;
 			if ( dvb.at(i)->isTuned() ) {
 				if ( dvb.at(i)->getCurrentTransponder()==chan->tp ) {
 					d1 = dvb.at(i);
@@ -1166,7 +1259,8 @@ void DvbPanel::finalZap( DvbStream *d, ChannelDesc *chan, bool setAudio, int nap
 				break;
 			}
 		}
-		if ( !d1 && d2 ) d1 = d2;
+		if ( !d1 && d2 )
+			d1 = d2;
 	}
 
 	if ( !d1 ) {
@@ -1195,12 +1289,15 @@ void DvbPanel::finalZap( DvbStream *d, ChannelDesc *chan, bool setAudio, int nap
 		audioComb->clear();
 		for ( i=0; i<chan->napid; i++ ) {
 			s = t.setNum( chan->apid[i].pid );
-			if ( !chan->apid[i].lang.isEmpty() ) s = s+"("+chan->apid[i].lang+")";
-			if ( chan->apid[i].ac3 ) s = s+"(ac3)";
+			if ( !chan->apid[i].lang.isEmpty() )
+				s = s+"("+chan->apid[i].lang+")";
+			if ( chan->apid[i].ac3 )
+				s = s+"(ac3)";
 			audioComb->insertItem( s );
 		}
 		audioComb->setCurrentItem( apidn );
-		if ( chan->napid>1 && ret==0 ) audioComb->setEnabled( true );
+		if ( chan->napid>1 && ret==0 )
+			audioComb->setEnabled( true );
 	}
 
 	fprintf( stderr, "Tuning delay : %d ms\n", tm.elapsed() );
@@ -1211,7 +1308,8 @@ void DvbPanel::finalZap( DvbStream *d, ChannelDesc *chan, bool setAudio, int nap
 		QTimer::singleShot(300, this, SIGNAL(showPlayer()));
 		showOsdTimer.start( 2000, true );
 	}
-	else emit dvbStop();
+	else
+		emit dvbStop();
 }
 
 
@@ -1227,10 +1325,12 @@ void DvbPanel::pauseLiveTV()
 			break;
 		}
 	}
-	if ( !d ) return;
+	if ( !d )
+		return;
 
 	timeShiftFileName = dvbConfig->shiftDir+"DVBLive-"+QDateTime::currentDateTime().toString( Qt::ISODate )+".ts";
-	if ( d->doPause( timeShiftFileName ) ) emit setTimeShiftFilename( timeShiftFileName );
+	if ( d->doPause( timeShiftFileName ) )
+		emit setTimeShiftFilename( timeShiftFileName );
 }
 
 
@@ -1284,15 +1384,19 @@ bool DvbPanel::getChannelList()
 		while ( !tt.eof() ) {
 			s = tt.readLine();
 			if ( s.startsWith("#") ) {
-				if ( s.contains("KaxTV") ) break;
+				if ( s.contains("KaxTV") )
+					break;
 				continue;
 			}
 			chan = new ChannelDesc();
 			pos = s.find("|");
 			c = s.left( pos );
-			if ( c=="TV" || c=="TVC" ) chan->type=1;
-			else chan->type=2;
-			if ( c=="TVC" || c=="RAC" ) chan->fta=1;
+			if ( c=="TV" || c=="TVC" )
+				chan->type=1;
+			else
+				chan->type=2;
+			if ( c=="TVC" || c=="RAC" )
+				chan->fta=1;
 			s = s.right( s.length()-pos-1 );
 			pos = s.find("|");
 			chan->name = s.left( pos );
@@ -1329,9 +1433,12 @@ bool DvbPanel::getChannelList()
 			s = s.right( s.length()-pos-1 );
 			pos = s.find("|");
 			c = s.left(pos);
-			if ( c.startsWith("T") ) chan->tp.type=FE_OFDM;
-			else if ( c.startsWith("C") ) chan->tp.type=FE_QAM;
-			else chan->tp.type=FE_QPSK;
+			if ( c.startsWith("T") )
+				chan->tp.type=FE_OFDM;
+			else if ( c.startsWith("C") )
+				chan->tp.type=FE_QAM;
+			else
+				chan->tp.type=FE_QPSK;
 			c.remove( 0, 1 );
 			chan->tp.source = c;
 			s = s.right( s.length()-pos-1 );
@@ -1461,15 +1568,20 @@ bool DvbPanel::getChannelList()
 			it = new KListViewItem( channelsCb, QString().sprintf("%04d", chan->num), chan->name );
 			it->setDragEnabled( true );
 			if ( chan->type==1 ) {
-				if ( chan->fta ) it->setPixmap( 1, tvcPix );
-				else it->setPixmap( 1, tvPix );
+				if ( chan->fta )
+					it->setPixmap( 1, tvcPix );
+				else
+					it->setPixmap( 1, tvPix );
 			}
 			else {
-				if ( chan->fta ) it->setPixmap( 1, racPix );
-				else it->setPixmap( 1, raPix );
+				if ( chan->fta )
+					it->setPixmap( 1, racPix );
+				else
+					it->setPixmap( 1, raPix );
 			}
 			channels.append( chan );
-			if ( chan->num<=0 ) chan->num = channels.count();
+			if ( chan->num<=0 )
+				chan->num = channels.count();
 
 		}
 		ret = true;
@@ -1494,19 +1606,25 @@ bool DvbPanel::saveChannelList()
 		for( i=0; i<(int)channels.count(); i++ ) {
 			chan = channels.at(i);
 			if ( chan->type==1 ) {
-				if ( chan->fta ) tt<<"TVC|";
-				else tt<<"TV|";
+				if ( chan->fta )
+					tt<<"TVC|";
+				else
+					tt<<"TV|";
 			}
 			else {
-				if ( chan->fta ) tt<<"RAC|";
-				else tt<<"RA|";
+				if ( chan->fta )
+					tt<<"RAC|";
+				else
+					tt<<"RA|";
 			}
 			tt<< chan->name+"|";
 			tt<< s.setNum(chan->vpid)+"|";
 			for ( k=0; k<chan->napid; k++ ) {
 				tt<< s.setNum(chan->apid[k].pid);
-				if ( !chan->apid[k].lang.isEmpty() ) tt<< "("+chan->apid[k].lang+")";
-				if ( chan->apid[k].ac3 ) tt<< "(ac3)";
+				if ( !chan->apid[k].lang.isEmpty() )
+					tt<< "("+chan->apid[k].lang+")";
+				if ( chan->apid[k].ac3 )
+					tt<< "(ac3)";
 				tt<< ",";
 			}
 			tt<< "|";
@@ -1522,8 +1640,10 @@ bool DvbPanel::saveChannelList()
 			tt<< "|";
 			tt<< s.setNum(chan->tp.freq)+"|";
 			tt<< s.setNum(chan->tp.sr)+"|";
-			if ( chan->tp.pol=='h'  ) tt<< "h|";
-			else tt<< "v|";
+			if ( chan->tp.pol=='h'  )
+				tt<< "h|";
+			else
+				tt<< "v|";
 			switch ( chan->tp.coderateH ) {
 				case FEC_NONE : tt<< "0|"; break;
 				case FEC_1_2 : tt<< "12|"; break;
@@ -1619,7 +1739,8 @@ bool DvbPanel::getTimerList()
 		QTextStream tt( &f );
 		while ( !tt.eof() ) {
 			s = tt.readLine();
-			if ( s.startsWith("#") ) continue;
+			if ( s.startsWith("#") )
+				continue;
 			t = new RecTimer();
 			pos = s.find("|");
 			t->name = s.left( pos );
@@ -1663,7 +1784,8 @@ bool DvbPanel::saveTimerList()
 		tt<<"#Generated by Kaffeine 0.5\n";
 		for( i=0; i<(int)timers.count(); i++ ) {
 			t = timers.at(i);
-			if ( t->running && !t->mode ) continue;
+			if ( t->running && !t->mode )
+				continue;
 			tt<< t->name+"|";
 			tt<< t->channel+"|";
 			tt<< t->begin.toString("yyyy-MM-ddThh:mm:ss")+"|";
