@@ -4,7 +4,7 @@
     begin                : Tue Dec 16 2003
     copyright            : (C) 2003-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/07/21 19:40:30 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -74,7 +74,8 @@ bool DVBsection::openFilter( int pid, int tid, int timeout, bool checkcrc )
 		perror ("open failed");
 		return false;
 	}
-	if ( !setFilter( pid, tid, timeout, checkcrc ) ) return false;
+	if ( !setFilter( pid, tid, timeout, checkcrc ) )
+		return false;
 	return true;
 }
 
@@ -92,7 +93,8 @@ bool DVBsection::setFilter( int pid, int tid, int timeout, bool checkcrc )
 		sctfilter.filter.mask[0] = 0xff;
 	}
 	sctfilter.flags = DMX_IMMEDIATE_START;
-	if ( checkcrc ) sctfilter.flags|= DMX_CHECK_CRC;
+	if ( checkcrc )
+		sctfilter.flags|= DMX_CHECK_CRC;
 	sctfilter.timeout = timeout;
 
 	if ( ioctl( fdDemux, DMX_SET_FILTER, &sctfilter ) < 0 ) {
@@ -128,8 +130,10 @@ unsigned int DVBsection::getBits( unsigned char *b, int offbits, int nbits )
 	buf = b+(offbits/8);
 	offbits %=8;
 	nbytes = (offbits+nbits)/8;
-	if ( ((offbits+nbits)%8)>0 ) nbytes++;
-	for ( i=0; i<nbytes; i++ ) ret += buf[i]<<((nbytes-i-1)*8);
+	if ( ((offbits+nbits)%8)>0 )
+		nbytes++;
+	for ( i=0; i<nbytes; i++ )
+		ret += buf[i]<<((nbytes-i-1)*8);
 	i = (4-nbytes)*8+offbits;
 	ret = ((ret<<i)>>i)>>((nbytes*8)-nbits-offbits);
 
@@ -144,12 +148,15 @@ QString DVBsection::getText( unsigned char *buf, int length )
 	QString s;
 	int i;
 
-	if ( length==0 ) return "";
+	if ( length==0 )
+		return "";
 
-	if ( buf[0]<0x10 ) index=1;
+	if ( buf[0]<0x10 )
+		index=1;
 
 	for ( i=index; i<length; i++ ) {  // removes control codes
-		if ( buf[i]>=0x20 && (buf[i]<0x80 || buf[i]>0x9f) ) s+= buf[i];
+		if ( buf[i]>=0x20 && (buf[i]<0x80 || buf[i]>0x9f) )
+			s+= buf[i];
 	}
 
 	return s.stripWhiteSpace();
@@ -190,8 +197,10 @@ QDate DVBsection::getDate( unsigned char *buf )
 	j = (int)(i*365.25);
 	m = (int)((mjd-14956.1-j)/30.6001);
 	D = mjd-14956-j-(int)(m*30.6001);
-	if ( m==14 || m==15 ) k = 1;
-	else k = 0;
+	if ( m==14 || m==15 )
+		k = 1;
+	else
+		k = 0;
 	Y = i+k+1900;
 	M = m-1-k*12;
 
@@ -235,8 +244,10 @@ QDateTime DVBsection::getDateTime( unsigned char *buf )
 	j = (int)(i*365.25);
 	m = (int)((mjd-14956.1-j)/30.6001);
 	t->tm_mday = mjd-14956-j-(int)(m*30.6001);
-	if ( m==14 || m==15 ) k = 1;
-	else k = 0;
+	if ( m==14 || m==15 )
+		k = 1;
+	else
+		k = 0;
 	t->tm_year = i+k;
 	t->tm_mon = m-1-k*12-1;
 	t->tm_sec = ((getBits(buf+2,16,4)*10)+getBits(buf+2,20,4))%60;
@@ -250,7 +261,8 @@ QDateTime DVBsection::getDateTime( unsigned char *buf )
 		t = localtime(&p);
 		return QDateTime( QDate( t->tm_year+1900, t->tm_mon+1, t->tm_mday ), QTime( t->tm_hour, t->tm_min, t->tm_sec ) );
 	}
-	else return QDateTime( QDate( 1970, 1, 1 ), QTime( 0, 0, 0 ) );
+	else
+		return QDateTime( QDate( 1970, 1, 1 ), QTime( 0, 0, 0 ) );
 }
 
 #include "dvbsection.moc"
