@@ -4,7 +4,7 @@
     begin                : 2004
     copyright            : (C) 2003-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/07/21 19:40:30 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -76,7 +76,8 @@ bool NitSection::getSection( int pid, int tid, int timeout )
 	int last=1, current=0, loop=0;
 	QValueList<int> list;
 
-	if ( !setFilter( pid, tid, timeout ) ) return false;
+	if ( !setFilter( pid, tid, timeout ) )
+		return false;
 
 	do {
 		if ( poll(pf,1,timeout)>0 ){
@@ -84,9 +85,11 @@ bool NitSection::getSection( int pid, int tid, int timeout )
 				n = read( fdDemux, buf, 4096 );
 				skip = 0;
 			}
-			else skip++;
+			else
+				skip++;
 		}
-		else skip++;
+		else
+			skip++;
 
 		if ( skip || n<4 ) {
 			fprintf(stderr,"\nInvalid section length or timeout : pid=%d\n\n", pid);
@@ -102,7 +105,8 @@ bool NitSection::getSection( int pid, int tid, int timeout )
 				break;
 			}
 		}
-		if ( i>-1 ) list.append( current );
+		if ( i>-1 )
+			list.append( current );
 		else {
 			loop++; // missing section ?
 			continue;
@@ -173,7 +177,8 @@ bool NitSection::tableNIT( unsigned char* buf )
 				break;
 			}
 		}
-		if ( !curtrans ) transponders->append( trans );
+		if ( !curtrans )
+			transponders->append( trans );
 		else {
 			for ( i=0; i<(int)trans->freqlist.count(); i++ ) {
 				for ( j=0; j<(int)curtrans->freqlist.count(); j++ ) {
@@ -204,8 +209,10 @@ void NitSection::satelliteDesc( unsigned char* buf, Transponder *trans )
 	s = t.setNum( getBits(buf,16,32), 16 );
 	trans->freq = s.toInt();
 	trans->freq /=100;
-	if ( getBits(buf,65,2) ) trans->pol = 'v';
-	else trans->pol = 'h';
+	if ( getBits(buf,65,2) )
+		trans->pol = 'v';
+	else
+		trans->pol = 'h';
 	s = t.setNum( getBits(buf,72,28), 16 );
 	trans->sr = s.toInt();
 	trans->sr /=10;
@@ -360,7 +367,8 @@ void DVBsi::serviceDesc( unsigned char* buf, ChannelDesc *desc )
 	desc->provider = getText( buf+4, i ).stripWhiteSpace();
 	j = getBits(buf+i,32,8);
 	desc->name = getText( buf+5+i, j ).stripWhiteSpace();
-	if ( desc->name.isEmpty() ) desc->name = "Unknown";
+	if ( desc->name.isEmpty() )
+		desc->name = "Unknown";
 	fprintf(stderr,"%s : sid=%d\n", desc->name.latin1(), desc->sid );
 }
 
@@ -425,7 +433,8 @@ bool DVBsi::tablePMT( unsigned char* buf )
 		}
 	}
 
-	if ( !desc ) return false;
+	if ( !desc )
+		return false;
 
 	length = getBits(buf,12,12);
 	loop = getBits(buf+10,4,12);
@@ -440,7 +449,8 @@ bool DVBsi::tablePMT( unsigned char* buf )
 			desc->vpid = pid;
 		}
 		if ( type==3 || type==4 ) {
-			if ( !desc->vpid ) desc->type=2;
+			if ( !desc->vpid )
+				desc->type=2;
 			nlang++;
 			if ( desc->napid<desc->maxapid ) {
 				desc->apid[(int)desc->napid].pid = pid;
@@ -459,7 +469,8 @@ bool DVBsi::tablePMT( unsigned char* buf )
 					}
 					break;
 				case 0x56 :
-					if ( type==6 ) desc->ttpid = pid;
+					if ( type==6 )
+						desc->ttpid = pid;
 					 break;
 				case 0x59 :  // DVB subtitle descriptor
 					ns = (int)desc->nsubpid;
@@ -535,7 +546,8 @@ bool DVBsi::getSection( int pid, int tid, int timeout )
 	int last=1, current=0, loop=0;
 	QValueList<int> list;
 
-	if ( !setFilter( pid, tid, timeout ) ) return false;
+	if ( !setFilter( pid, tid, timeout ) )
+		return false;
 
 	do {
 		if ( poll(pf,1,timeout)>0 ){
@@ -543,9 +555,11 @@ bool DVBsi::getSection( int pid, int tid, int timeout )
 				n = read( fdDemux, buf, 4096 );
 				skip = 0;
 			}
-			else skip++;
+			else
+				skip++;
 		}
-		else skip++;
+		else
+			skip++;
 
 		if ( skip || n<4 ) {
 			fprintf(stderr,"\nInvalid section length or timeout : pid=%d\n\n", pid);
@@ -561,7 +575,8 @@ bool DVBsi::getSection( int pid, int tid, int timeout )
 				break;
 			}
 		}
-		if ( i>-1 ) list.append( current );
+		if ( i>-1 )
+			list.append( current );
 		else {
 			loop++; // missing section ?
 			continue;
@@ -593,17 +608,20 @@ bool DVBsi::getSection( int pid, int tid, int timeout )
 
 void DVBsi::stop()
 {
-	if ( !isRunning ) return;
+	if ( !isRunning )
+		return;
 
 	isRunning = false;
 	if ( !wait(2000) ) {
 		terminate();
+		wait();
 		if ( ns ) {
 			ns->stop();
 			delete ns;
 			ns = 0;
 		}
-		if ( scanMode<2 ) dvb->stopScan();
+		if ( scanMode<2 )
+			dvb->stopScan();
 	}
 }
 
@@ -616,7 +634,8 @@ void DVBsi::out( bool stopscan )
 		delete ns;
 		ns = 0;
 	}
-	if ( stopscan ) dvb->stopScan();
+	if ( stopscan )
+		dvb->stopScan();
 	KApplication::kApplication()->postEvent( this, new QTimerEvent( TIMER_EVENT_SCAN_END ) );
 }
 
@@ -626,11 +645,13 @@ void DVBsi::go( QPtrList<Transponder> trans, int mode )
 {
 	int i;
 
-	if ( isRunning ) return;
+	if ( isRunning )
+		return;
 
 	scanMode = mode;
 	transponders.clear();
-	for ( i=0; i<(int)trans.count(); i++ ) transponders.append( new Transponder( *trans.at(i) ) );
+	for ( i=0; i<(int)trans.count(); i++ )
+		transponders.append( new Transponder( *trans.at(i) ) );
 	channels.clear();
 	isRunning = true;
 	start();
@@ -662,7 +683,10 @@ void DVBsi::run()
 	if ( scanMode<2 ) {
 		dvb->stopScan();
 		for ( i=0; i<(int)transponders.count(); i++ ) {
-			if ( !isRunning ) { out(); return; }
+			if ( !isRunning ) {
+				out();
+				return;
+			}
 			chan.tp = *transponders.at(i);
 			usleep(100000);
 			if ( !dvb->tuneDvb( &chan, false ) ) {
@@ -688,18 +712,25 @@ void DVBsi::run()
 			nitEnded = false;
 			ns = new NitSection( &transponders, &nitEnded, &ok, cardNum ); //NIT
 			getSection( 0x11, 0x42 );         //SDT
-			if ( !isRunning )  { out(); return; }
+			if ( !isRunning ) {
+				out();
+				return;
+			}
 			getSection( 0x00, 0x00 );         //PAT
 			for ( ; j<(int)channels.count(); j++ ) {
 				if ( channels.at( j )->pmtpid==0 ) {
 					channels.at(j)->completed = 1;
 					continue;
 				}
-				if ( !isRunning )  { out(); return; }
+				if ( !isRunning ) {
+					out();
+					return;
+				}
 				getSection( channels.at( j )->pmtpid, 0x02 );    //PMTs
 				tsid = channels.at(j)->tp.tsid;
 				channels.at(j)->tp = *transponders.at(i);
-				if ( channels.at(j)->tp.tsid==0 ) channels.at(j)->tp.tsid = tsid;
+				if ( channels.at(j)->tp.tsid==0 )
+					channels.at(j)->tp.tsid = tsid;
 				channels.at(j)->completed = 1;
 			}
 			while( !nitEnded ) {
@@ -707,7 +738,8 @@ void DVBsi::run()
 					ns->stop();
 					break;
 				}
-				else msleep( 50 );
+				else
+					msleep( 50 );
 			}
 			delete ns;
 			ns = 0;
@@ -726,7 +758,10 @@ void DVBsi::run()
 				channels.at(j)->completed = 1;
 				continue;
 			}
-			if ( !isRunning )  { out(false); return; }
+			if ( !isRunning ) {
+				out(false);
+				return;
+			}
 			getSection( channels.at( j )->pmtpid, 0x02 );    //PMTs
 			tsid = channels.at(j)->tp.tsid;
 			channels.at(j)->tp = trans;
@@ -750,15 +785,24 @@ bool DVBsi::listChannels()
 
 	for ( i=0; i<(int)channels.count(); i++ ) {
 		ac3 = false;
-		if ( channels.at( i )->nsubpid==0 ) continue;
-		if ( channels.at( i )->pmtpid==0 ) continue;
-		if ( channels.at(i)->name.isEmpty() ) continue;
-		if ( channels.at( i )->type<1 ) continue;
-		if ( channels.at( i )->type>2 ) continue;
-		if ( channels.at( i )->type==1 && channels.at(i)->vpid==0 ) continue;
-		if ( channels.at( i )->type==1 && channels.at(i)->napid==0 ) continue;
-		if ( channels.at( i )->type==2 && channels.at(i)->napid==0 ) continue;
-		if ( channels.at( i )->type==2 && channels.at(i)->vpid!=0 ) continue;
+		if ( channels.at( i )->nsubpid==0 )
+			continue;
+		if ( channels.at( i )->pmtpid==0 )
+			continue;
+		if ( channels.at(i)->name.isEmpty() )
+			continue;
+		if ( channels.at( i )->type<1 )
+			continue;
+		if ( channels.at( i )->type>2 )
+			continue;
+		if ( channels.at( i )->type==1 && channels.at(i)->vpid==0 )
+			continue;
+		if ( channels.at( i )->type==1 && channels.at(i)->napid==0 )
+			continue;
+		if ( channels.at( i )->type==2 && channels.at(i)->napid==0 )
+			continue;
+		if ( channels.at( i )->type==2 && channels.at(i)->vpid!=0 )
+			continue;
 
 		s = "|"+channels.at(i)->name;
 		s = s+"|"+t.setNum(channels.at(i)->tp.freq);
