@@ -4,7 +4,7 @@
     begin                : Mon Jan 20 2003
     copyright            : (C) 2003-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/08/06 23:28:07 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
 
     some code from :
 		dvbstream (GPL), Copyright (C) Dave Chapman 2001,2002
@@ -376,14 +376,14 @@ bool DvbStream::tuneDvb( ChannelDesc *chan, bool dvr )
 			return false;
 		}
 		fprintf(stderr,"polling....\n");
-		if (poll(pf,1,10000)){
-			if (pf[0].revents & POLLIN){
+		if (poll(pf,1,10000)) {
+			if (pf[0].revents & POLLIN) {
 				fprintf(stderr,"Getting frontend event\n");
 				if (++eventCount > 7) { // 7 is just a working guess...
 					closeFe();
 					return false;
 				}
-				if ((status = ioctl(fdFrontend, FE_GET_EVENT, &event)) < 0){
+				if ((status = ioctl(fdFrontend, FE_GET_EVENT, &event)) < 0) {
 					if (status != -EOVERFLOW) {
 						perror("FE_GET_EVENT");
 						closeFe();
@@ -520,7 +520,8 @@ bool DvbStream::setPids( DVBout *o, int napid )
 	if ( o->channel.subpid[0].pid )
 		pidList.append( o->channel.subpid[0].pid );
 
-	//if ( (ndmx+pidList.count())>MAX_CHANNELS ) return false;
+	/*if ( (ndmx+pidList.count())>MAX_CHANNELS )
+		return false;*/
 
 	for ( i=0; i<(int)pidList.count(); i++ ) {
 		if ( ( dmx = open( demuxName, O_RDWR)) < 0 ) {
@@ -528,7 +529,8 @@ bool DvbStream::setPids( DVBout *o, int napid )
 			perror("DEMUX DEVICE: ");
 			return false;
 		}
-		else o->dmx.append(dmx);
+		else
+			o->dmx.append(dmx);
 	}
 
 	for ( i=0; i<(int)pidList.count(); i++ ) {
@@ -644,7 +646,8 @@ void DvbStream::run()
 				thWrite = 0;
 			}
 		}
-		else usleep(1000);
+		else
+			usleep(1000);
 	}
 
 	fprintf(stderr,"dvbstream::run() end\n");
@@ -800,7 +803,8 @@ bool DvbStream::startBroadcast( QPtrList<ChannelDesc> *list, Ts2Rtp *rtp )
 				i = -1;
 				break;
 			}
-			else usleep(100000);
+			else
+				usleep(100000);
 		}
 		if ( i<0 )
 			stop = true;
@@ -827,7 +831,8 @@ bool DvbStream::startBroadcast( QPtrList<ChannelDesc> *list, Ts2Rtp *rtp )
 				removeOut( o );
 				o = 0;
 			}
-			else newout = true;
+			else
+				newout = true;
 		}
 
 		if ( o ) {
@@ -837,7 +842,8 @@ bool DvbStream::startBroadcast( QPtrList<ChannelDesc> *list, Ts2Rtp *rtp )
 					removeOut( o );
 				}
 			}
-			else no++;
+			else
+				no++;
 		}
 	}
 
@@ -912,7 +918,8 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 				i = -1;
 				break;
 			}
-			else usleep(100000);
+			else
+				usleep(100000);
 		}
 		if ( i<0 )
 			stop = true;
@@ -982,7 +989,8 @@ int DvbStream::goLive( ChannelDesc *chan, const QString &pipeName, int &napid )
 				i = -1;
 				break;
 			}
-			else usleep(100000);
+			else
+				usleep(100000);
 		}
 		if ( i<0 )
 			stop = true;
