@@ -4,7 +4,7 @@
     begin                : Wed Jan 7 2004
     copyright            : (C) 2004-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/07/31 19:04:48 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -131,6 +131,9 @@ void KEvents::mouseClickedSlot( int btn, QListViewItem *it, const QPoint &p, int
 	int i=c;
 	QPoint pt=p;
 	QString s;
+
+	if ( !it )
+		return;
 	EListViewItem *ei = (EListViewItem*)it;
 
 	switch ( btn ) {
@@ -139,7 +142,8 @@ void KEvents::mouseClickedSlot( int btn, QListViewItem *it, const QPoint &p, int
 			pop->insertItem( i18n("View all programs"), 1 );
 			pop->insertSeparator();
 			pop->insertItem( i18n("Add to timers"), 2 );
-			if ( ei->event->running==4 ) pop->setItemEnabled( 2, false );
+			if ( ei->event->running==4 )
+				pop->setItemEnabled( 2, false );
 			i = 0;
 			i = pop->exec( QCursor::pos() );
 			switch ( i ) {
@@ -226,9 +230,11 @@ void KEvents::reset()
 {
 	int i;
 
-	if ( checkTimer.isActive() ) checkTimer.stop();
+	if ( checkTimer.isActive() )
+		checkTimer.stop();
 	listView->clear();
-	for ( i=0; i<(int)nEvents.count(); i++ ) nEvents[i] = 0;
+	for ( i=0; i<(int)nEvents.count(); i++ )
+		nEvents[i] = 0;
 	checkTimer.start( 100 );
 }
 
@@ -246,10 +252,13 @@ void KEvents::checkNewEvent()
 		for ( j=nEvents[k]; j<(int)dvb->at(k)->dvbEvents->events.count(); j++ ) {
 			nEvents[k]++;
 			desc = dvb->at(k)->dvbEvents->events.at(j);
-			if ( mode==1 && desc->tid>0x4f ) continue;
+			if ( mode==1 && desc->tid>0x4f )
+				continue;
 			if ( mode==2 ) {
-				if ( !chan ) continue;
-				if ( desc->source!=chan->tp.source || desc->sid!=chan->sid || desc->tsid!=chan->tp.tsid ) continue;
+				if ( !chan )
+					continue;
+				if ( desc->source!=chan->tp.source || desc->sid!=chan->sid || desc->tsid!=chan->tp.tsid )
+					continue;
 				channel = chan->name;
 			}
 			else {
@@ -261,12 +270,14 @@ void KEvents::checkNewEvent()
 						break;
 					}
 				}
-				if ( ret ) continue;
+				if ( ret )
+					continue;
 			}
 			begin = desc->startDateTime.toString( Qt::LocalDate );
 			duration = desc->duration.toString("hh:mm");
 			title = desc->title;
-			if ( title.isEmpty() ) continue;
+			if ( title.isEmpty() )
+				continue;
 			itt = new EListViewItem( (QListView*)listView, channel.latin1(), begin, duration, title.latin1(), desc );
 		}
 	}
@@ -276,7 +287,8 @@ void KEvents::checkNewEvent()
 
 KEvents::~KEvents()
 {
-	if ( checkTimer.isActive() ) checkTimer.stop();
+	if ( checkTimer.isActive() )
+		checkTimer.stop();
 }
 
 #include "kevents.moc"
