@@ -4,7 +4,7 @@
     begin                : Tue Mar 30 2004
     copyright            : (C) 2004-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/04/27 12:15:28 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -125,9 +125,12 @@ void KRecord::refresh()
 		s = s+ti->name;*/
 		s = ti->name;
 		itt = new KListViewItem( (QListView*)list, "", s, ti->channel, ti->begin.toString("hh:mm dd/MM/yy"), ti->duration.toString("hh:mm") );
-		if ( ti->mode ) itt->setPixmap( 0, yesRepeat );
-		if ( ti->running ) itt->setPixmap( 1, isRecording );
-		if ( after ) itt->moveItem( after );
+		if ( ti->mode )
+			itt->setPixmap( 0, yesRepeat );
+		if ( ti->running )
+			itt->setPixmap( 1, isRecording );
+		if ( after )
+			itt->moveItem( after );
 	}
 }
 
@@ -148,9 +151,12 @@ void KRecord::newTimer()
 		*t = dlg.timer;
 		after = where( t, true );
 		itt = new KListViewItem( (QListView*)list, "", t->name, t->channel, t->begin.toString("hh:mm dd/MM/yy"), t->duration.toString("hh:mm") );
-		if ( t->mode ) itt->setPixmap( 0, yesRepeat );
-		if ( t->running ) itt->setPixmap( 1, isRecording );
-		if ( after ) itt->moveItem( after );
+		if ( t->mode )
+			itt->setPixmap( 0, yesRepeat );
+		if ( t->running )
+			itt->setPixmap( 1, isRecording );
+		if ( after )
+			itt->moveItem( after );
 	}
 	else delete t;
 }
@@ -172,7 +178,8 @@ void KRecord::editTimer()
 		i++;
 		it = it->nextSibling();
 	}
-	if ( r<0 ) return;
+	if ( r<0 )
+		return;
 
 	tn = timers->at(r);
 	KTimerEditor dlg( false, channelsList, *tn, this );
@@ -183,10 +190,12 @@ void KRecord::editTimer()
 				if ( tn->running ) {
 					int ms = tn->begin.time().secsTo( QTime::currentTime() );
 					ms = ((dlg.timer.duration.hour()*3600+dlg.timer.duration.minute()*60)-ms)*1000;
-					if ( ms<2000 ) ms = 0;
+					if ( ms<2000 )
+						ms = 0;
 					tn->duration = dlg.timer.duration;
 					emit updateTimer( tn, ms );
-					if ( ms ) refresh();
+					if ( ms )
+						refresh();
 				}
 				else {
 					timers->remove( tn );
@@ -212,8 +221,10 @@ void KRecord::deleteTimer()
 	it = list->firstChild();
        while ( it!=0 ) {
 		if ( it->isSelected() )  {
-			if ( timers->at(i)->mode ) ret = KMessageBox::questionYesNoCancel( this, i18n("This timer is repeated. Do you want to skip the current job or delete the timer ?"), i18n("Warning"), KGuiItem(i18n("Skip current"), icon->loadIconSet("next", KIcon::Small) ), KGuiItem(i18n("Delete"), icon->loadIconSet("editcut", KIcon::Small) ) );
-			else ret = KMessageBox::questionYesNo( this, i18n("Delete the selected timer ?") );
+			if ( timers->at(i)->mode )
+				ret = KMessageBox::questionYesNoCancel( this, i18n("This timer is repeated. Do you want to skip the current job or delete the timer ?"), i18n("Warning"), KGuiItem(i18n("Skip current"), icon->loadIconSet("next", KIcon::Small) ), KGuiItem(i18n("Delete"), icon->loadIconSet("editcut", KIcon::Small) ) );
+			else
+				ret = KMessageBox::questionYesNo( this, i18n("Delete the selected timer ?") );
 			if ( ret==KMessageBox::Yes ) {
 				emit updateTimer( timers->at(i), 0 );
 			}
@@ -240,10 +251,13 @@ QListViewItem* KRecord::where( RecTimer *rt, bool add )
 
 	for ( i=0; i<(int)timers->count(); i++ ) {
 		t = timers->at(i);
-		if ( rt->begin>t->begin ) r=i+1;
+		if ( rt->begin>t->begin )
+			r=i+1;
 	}
-	if ( add ) timers->insert( r, rt );
-	if ( !r ) return ret;
+	if ( add )
+		timers->insert( r, rt );
+	if ( !r )
+		return ret;
 
 	it = list->firstChild();
 	i=0;
