@@ -4,7 +4,7 @@
     begin                : Wed Mar 31 2004
     copyright            : (C) 2004-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/04/27 12:15:28 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -48,14 +48,18 @@ KTimerEditor::KTimerEditor( bool newone, QStringList &chanList, RecTimer t, QWid
 	grid->addWidget( lab, 3, 0 );
 	duration = new QTimeEdit( this );
 	grid->addWidget( duration, 3, 1 );
-	lab = new QLabel( i18n("Record as :"), this );
+	lab = new QLabel( i18n("End :"), this );
 	grid->addWidget( lab, 4, 0 );
+	end = new QDateTimeEdit( this );
+	grid->addWidget( end, 4, 1 );
+	lab = new QLabel( i18n("Record as :"), this );
+	grid->addWidget( lab, 5, 0 );
 	typeComb = new QComboBox( this );
-	grid->addWidget( typeComb, 4, 1 );
+	grid->addWidget( typeComb, 5, 1 );
 	repeatBtn = new KPushButton( this );
-	grid->addWidget( repeatBtn, 5, 0 );
+	grid->addWidget( repeatBtn, 6, 0 );
 	repeatLab = new QLabel( this );
-	grid->addWidget( repeatLab, 5, 1 );
+	grid->addWidget( repeatLab, 6, 1 );
 
 	QFrame *line = new QFrame( this, "line1" );
 	line->setFrameStyle( QFrame::HLine );
@@ -88,7 +92,6 @@ KTimerEditor::KTimerEditor( bool newone, QStringList &chanList, RecTimer t, QWid
 	if ( newone ) {
 		begin->setDateTime( QDateTime::currentDateTime() );
 		duration->setTime( QTime(2,0,0) );
-
 	}
 	else {
 		nameLe->setText( timer.name );
@@ -131,16 +134,49 @@ KTimerEditor::KTimerEditor( bool newone, QStringList &chanList, RecTimer t, QWid
 	connect( okBtn, SIGNAL(clicked()), this, SLOT(accept()) );
 	connect( cancelBtn, SIGNAL(clicked()), this, SLOT(reject()) );
 	connect( repeatBtn, SIGNAL(clicked()), this, SLOT(setRepeat()) );
+	connect( begin, SIGNAL(valueChanged(const QDateTime&)), this, SLOT(setMaxEnd(const QDateTime&)) );
+	connect( end, SIGNAL(valueChanged(const QDateTime&)), this, SLOT(setDuration(const QDateTime&)) );
+	connect( duration, SIGNAL(valueChanged(const QTime&)), this, SLOT(setEnd(const QTime&)) );
+	setMaxEnd( begin->dateTime() );
         delete icon;
 }
 
 
 
+void KTimerEditor::setMaxEnd( const QDateTime &dt )
+{
+	QDateTime max = dt.addSecs( 23*3600+59*60+59 );
+	end->dateEdit()->setMinValue( dt.date() );
+	end->dateEdit()->setMaxValue( max.date() );
+	setEnd( duration->time() );
+}
+
+
+
+void KTimerEditor::setDuration( const QDateTime &dt )
+{
+	disconnect( duration, SIGNAL(valueChanged(const QTime&)), this, SLOT(setEnd(const QTime&)) );
+	duration->setTime( QTime().addSecs( begin->dateTime().secsTo( dt ) ) );
+	connect( duration, SIGNAL(valueChanged(const QTime&)), this, SLOT(setEnd(const QTime&)) );
+}
+
+
+
+void KTimerEditor::setEnd( const QTime &t )
+{
+	disconnect( end, SIGNAL(valueChanged(const QDateTime&)), this, SLOT(setDuration(const QDateTime&)) );
+	end->setDateTime( begin->dateTime().addSecs( QTime().secsTo( t ) ) );
+	connect( end, SIGNAL(valueChanged(const QDateTime&)), this, SLOT(setDuration(const QDateTime&)) );
+}
+
+
+
 void KTimerEditor::setRepeat()
 {
 	CronTimer dlg( timer.mode, this );
 
-	if ( dlg.exec()==CronTimer::Accepted ) timer.mode = dlg.getMode();
+	if ( dlg.exec()==CronTimer::Accepted )
+		timer.mode = dlg.getMode();
 	switch ( timer.mode ) {
 		case CronTimer::Noone : repeatLab->setText( i18n("None") ); break;
 		case CronTimer::Daily : repeatLab->setText( i18n("Daily") ); break;
@@ -176,7 +212,8 @@ void KTimerEditor::accept()
 	}
 
 	timer.duration = duration->time();
-	if ( timer.running ) done( Accepted );
+	if ( timer.running )
+		done( Accepted );
 
 	switch ( typeComb->currentItem() ) {
 		case 0 : timer.filetype = OutTS; break;
