@@ -4,7 +4,7 @@
     begin                : Mon Mar 22 2004
     copyright            : (C) 2004-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/07/21 19:40:30 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -59,7 +59,8 @@ ScanDialog::ScanDialog( QPtrList<DvbStream> *d, QPtrList<ChannelDesc> *ch, QSize
 
 	for ( i=0; i<(int)dvb->count(); i++ ) {
 		tmp = dvb->at(i)->getSources();
-		for ( j=0; j<(int)tmp.count(); j++ ) list.append( tmp[j] );
+		for ( j=0; j<(int)tmp.count(); j++ )
+			list.append( tmp[j] );
 	}
 	searchComb->insertStringList( list );
 
@@ -101,12 +102,16 @@ ScanDialog::ScanDialog( QPtrList<DvbStream> *d, QPtrList<ChannelDesc> *ch, QSize
 		chan = chandesc->at(i);
 		it = new QListViewItem( channelsList, chan->name );
 		if ( chan->type==1 ) {
-			if ( chan->fta ) it->setPixmap( 0, tvcPix );
-			else it->setPixmap( 0, tvPix );
+			if ( chan->fta )
+				it->setPixmap( 0, tvcPix );
+			else
+				it->setPixmap( 0, tvPix );
 		}
 		else {
-			if ( chan->fta ) it->setPixmap( 0, racPix );
-			else it->setPixmap( 0, raPix );
+			if ( chan->fta )
+				it->setPixmap( 0, racPix );
+			else
+				it->setPixmap( 0, raPix );
 		}
 	}
 
@@ -145,7 +150,8 @@ ScanDialog::ScanDialog( QPtrList<DvbStream> *d, QPtrList<ChannelDesc> *ch, QSize
 
 void ScanDialog::slotChannelChanged( QListViewItem *_channel, const QPoint &, int )
 {
-	if ( !_channel ) return;
+	if ( !_channel )
+		return;
 	QPixmap pix;
 	QString s = _channel->text(0);
 	if ( edit( s, pix ) ) {
@@ -166,8 +172,10 @@ void ScanDialog::setDvb( int index )
 		list = dvb->at(i)->getSources();
 		pos+= list.count();
 		if ( index<pos ) {
-			if ( checkTimer.isActive() ) checkTimer.stop();
-			if ( progressTimer.isActive() ) progressTimer.stop();
+			if ( checkTimer.isActive() )
+				checkTimer.stop();
+			if ( progressTimer.isActive() )
+				progressTimer.stop();
 			disconnect( ds, SIGNAL(snrStatus(int)), snr, SLOT(setProgress(int)) );
 			disconnect( ds, SIGNAL(signalStatus(int)), signal, SLOT(setProgress(int)) );
 			disconnect( ds, SIGNAL(lockStatus(bool)), this, SLOT(setLock(bool)) );
@@ -193,7 +201,8 @@ void ScanDialog::pop( QListViewItem *it, const QPoint &pos, int col )
 {
 	QPoint p=pos;
 
-	if ( !it ) return;
+	if ( !it )
+		return;
 
 	int i=col;
 	QPixmap pix;
@@ -225,7 +234,8 @@ void ScanDialog::pop( QListViewItem *it, const QPoint &pos, int col )
 void ScanDialog::deleteChannel()
 {
 	QListViewItem *it = channelsList->currentItem();
-	if ( it ) deleteChannel( it->text(0) );
+	if ( it )
+		deleteChannel( it->text(0) );
 }
 
 
@@ -282,12 +292,16 @@ void ScanDialog::newChannel()
 		chandesc->append( new ChannelDesc( chan ) );
 		QListViewItem *it = new QListViewItem( channelsList, chan.name );
 		if ( chan.type==1 ) {
-			if ( chan.fta ) it->setPixmap( 0, tvcPix );
-			else it->setPixmap( 0, tvPix );
+			if ( chan.fta )
+				it->setPixmap( 0, tvcPix );
+			else
+				it->setPixmap( 0, tvPix );
 		}
 		else {
-			if ( chan.fta ) it->setPixmap( 0, racPix );
-			else it->setPixmap( 0, raPix );
+			if ( chan.fta )
+				it->setPixmap( 0, racPix );
+			else
+				it->setPixmap( 0, raPix );
 		}
 	}
 }
@@ -299,7 +313,8 @@ void ScanDialog::deleteAll()
 	int i, ret;
 
 	ret = KMessageBox::questionYesNo( this, i18n("Do you really want to delete all channels ?") );
-	if ( ret!=KMessageBox::Yes ) return;
+	if ( ret!=KMessageBox::Yes )
+		return;
 	for ( i=0; i<(int)chandesc->count(); i++ ) {
 		dvbsi->channels.append( new ChannelDesc( *chandesc->at(i) ) );
 		addFound( chandesc->at(i), false );
@@ -317,7 +332,8 @@ bool ScanDialog::edit( QString &name, QPixmap &pix )
 	QStringList list;
 	int i;
 
-	for ( i=0; i<(int)searchComb->count(); i++ ) list.append( searchComb->text(i) );
+	for ( i=0; i<(int)searchComb->count(); i++ )
+		list.append( searchComb->text(i) );
 
 	for ( j=0; j<(int)chandesc->count(); j++ ) {
 		chan = chandesc->at(j);
@@ -332,12 +348,16 @@ bool ScanDialog::edit( QString &name, QPixmap &pix )
 		if ( ret==ChannelEditor::Accepted ) {
 			name = chan->name;
 			if ( chan->type==1 ) {
-				if ( chan->fta ) pix = tvcPix;
-				else pix = tvPix;
+				if ( chan->fta )
+					pix = tvcPix;
+				else
+					pix = tvPix;
 			}
 			else {
-				if ( chan->fta ) pix = racPix;
-				else pix = raPix;
+				if ( chan->fta )
+					pix = racPix;
+				else
+					pix = raPix;
 			}
 			return true;
 		}
@@ -356,9 +376,12 @@ void ScanDialog::parseTp( QString s, fe_type_t type, QString src )
 	s = s.stripWhiteSpace();
 	trans = new Transponder();
 	pos = s.find(" ");
-	if ( s.left(pos)=="T" ) trans->type=FE_OFDM;
-	else if ( s.left(pos)=="C" ) trans->type=FE_QAM;
-	else trans->type=FE_QPSK;
+	if ( s.left(pos)=="T" )
+		trans->type=FE_OFDM;
+	else if ( s.left(pos)=="C" )
+		trans->type=FE_QAM;
+	else
+		trans->type=FE_QPSK;
 	if ( trans->type!=type ) {
 		delete trans;
 		return;
@@ -381,82 +404,126 @@ void ScanDialog::parseTp( QString s, fe_type_t type, QString src )
 		trans->sr = s.left(pos).toULong()/1000;
 	}
 	else {
-		if ( s.left(pos)=="8MHz" ) trans->bandwidth = BANDWIDTH_8_MHZ;
-		else if ( s.left(pos)=="7MHz" ) trans->bandwidth = BANDWIDTH_7_MHZ;
-		else if ( s.left(pos)=="6MHz" ) trans->bandwidth = BANDWIDTH_6_MHZ;
-		else trans->bandwidth = BANDWIDTH_AUTO;
+		if ( s.left(pos)=="8MHz" )
+			trans->bandwidth = BANDWIDTH_8_MHZ;
+		else if ( s.left(pos)=="7MHz" )
+			trans->bandwidth = BANDWIDTH_7_MHZ;
+		else if ( s.left(pos)=="6MHz" )
+			trans->bandwidth = BANDWIDTH_6_MHZ;
+		else
+			trans->bandwidth = BANDWIDTH_AUTO;
 	}
 	s = s.right( s.length()-pos-1 );
 	s = s.stripWhiteSpace();
 	pos = s.find(" ");
-	if ( s.left(pos)=="1/2" ) trans->coderateH = FEC_1_2;
-	else if ( s.left(pos)=="2/3" ) trans->coderateH = FEC_2_3;
-	else if ( s.left(pos)=="3/4" ) trans->coderateH = FEC_3_4;
-	else if ( s.left(pos)=="4/5" ) trans->coderateH = FEC_4_5;
-	else if ( s.left(pos)=="5/6" ) trans->coderateH = FEC_5_6;
-	else if ( s.left(pos)=="6/7" ) trans->coderateH = FEC_6_7;
-	else if ( s.left(pos)=="7/8" ) trans->coderateH = FEC_7_8;
-	else if ( s.left(pos)=="8/9" ) trans->coderateH = FEC_8_9;
-	else if ( s.left(pos)=="NONE" ) trans->coderateH = FEC_NONE;
-	else trans->coderateH = FEC_AUTO;
+	if ( s.left(pos)=="1/2" )
+		trans->coderateH = FEC_1_2;
+	else if ( s.left(pos)=="2/3" )
+		trans->coderateH = FEC_2_3;
+	else if ( s.left(pos)=="3/4" )
+		trans->coderateH = FEC_3_4;
+	else if ( s.left(pos)=="4/5" )
+		trans->coderateH = FEC_4_5;
+	else if ( s.left(pos)=="5/6" )
+		trans->coderateH = FEC_5_6;
+	else if ( s.left(pos)=="6/7" )
+		trans->coderateH = FEC_6_7;
+	else if ( s.left(pos)=="7/8" )
+		trans->coderateH = FEC_7_8;
+	else if ( s.left(pos)=="8/9" )
+		trans->coderateH = FEC_8_9;
+	else if ( s.left(pos)=="NONE" )
+		trans->coderateH = FEC_NONE;
+	else
+		trans->coderateH = FEC_AUTO;
 	s = s.right( s.length()-pos-1 );
 	s = s.stripWhiteSpace();
 	pos = s.find(" ");
 	if ( trans->type==FE_OFDM ) {
-		if ( s.left(pos)=="1/2" ) trans->coderateL = FEC_1_2;
-		else if ( s.left(pos)=="2/3" ) trans->coderateL = FEC_2_3;
-		else if ( s.left(pos)=="3/4" ) trans->coderateL = FEC_3_4;
-		else if ( s.left(pos)=="4/5" ) trans->coderateL = FEC_4_5;
-		else if ( s.left(pos)=="5/6" ) trans->coderateL = FEC_5_6;
-		else if ( s.left(pos)=="6/7" ) trans->coderateL = FEC_6_7;
-		else if ( s.left(pos)=="7/8" ) trans->coderateL = FEC_7_8;
-		else if ( s.left(pos)=="8/9" ) trans->coderateL = FEC_8_9;
-		else if ( s.left(pos)=="NONE" ) trans->coderateL = FEC_NONE;
-		else trans->coderateL = FEC_AUTO;
-		
+		if ( s.left(pos)=="1/2" )
+			trans->coderateL = FEC_1_2;
+		else if ( s.left(pos)=="2/3" )
+			trans->coderateL = FEC_2_3;
+		else if ( s.left(pos)=="3/4" )
+			trans->coderateL = FEC_3_4;
+		else if ( s.left(pos)=="4/5" )
+			trans->coderateL = FEC_4_5;
+		else if ( s.left(pos)=="5/6" )
+			trans->coderateL = FEC_5_6;
+		else if ( s.left(pos)=="6/7" )
+			trans->coderateL = FEC_6_7;
+		else if ( s.left(pos)=="7/8" )
+			trans->coderateL = FEC_7_8;
+		else if ( s.left(pos)=="8/9" )
+			trans->coderateL = FEC_8_9;
+		else if ( s.left(pos)=="NONE" )
+			trans->coderateL = FEC_NONE;
+		else
+			trans->coderateL = FEC_AUTO;
+
 		if ( trans->coderateH==FEC_NONE )
 			trans->coderateH = FEC_AUTO;
 		if ( trans->coderateL==FEC_NONE )
 			trans->coderateL = FEC_AUTO;
-			
+
 		s = s.right( s.length()-pos-1 );
 		s = s.stripWhiteSpace();
 		pos = s.find(" ");
 	}
 	if ( trans->type!=FE_QPSK ) {
-		if ( s.left(pos)=="QPSK" ) trans->modulation = QPSK;
-		else if ( s.left(pos)=="QAM16" ) trans->modulation = QAM_16;
-		else if ( s.left(pos)=="QAM32" ) trans->modulation = QAM_32;
-		else if ( s.left(pos)=="QAM64" ) trans->modulation = QAM_64;
-		else if ( s.left(pos)=="QAM128" ) trans->modulation = QAM_128;
-		else if ( s.left(pos)=="QAM256" ) trans->modulation = QAM_256;
-		else trans->modulation = QAM_AUTO;
+		if ( s.left(pos)=="QPSK" )
+			trans->modulation = QPSK;
+		else if ( s.left(pos)=="QAM16" )
+			trans->modulation = QAM_16;
+		else if ( s.left(pos)=="QAM32" )
+			trans->modulation = QAM_32;
+		else if ( s.left(pos)=="QAM64" )
+			trans->modulation = QAM_64;
+		else if ( s.left(pos)=="QAM128" )
+			trans->modulation = QAM_128;
+		else if ( s.left(pos)=="QAM256" )
+			trans->modulation = QAM_256;
+		else
+			trans->modulation = QAM_AUTO;
 	}
 	if ( trans->type==FE_OFDM ) {
 		s = s.right( s.length()-pos-1 );
 		s = s.stripWhiteSpace();
 		pos = s.find(" ");
-		if ( s.left(pos)=="8k" ) trans->transmission = TRANSMISSION_MODE_8K;
-		else if ( s.left(pos)=="2k" ) trans->transmission = TRANSMISSION_MODE_2K;
-		else trans->transmission = TRANSMISSION_MODE_AUTO;
+		if ( s.left(pos)=="8k" )
+			trans->transmission = TRANSMISSION_MODE_8K;
+		else if ( s.left(pos)=="2k" )
+			trans->transmission = TRANSMISSION_MODE_2K;
+		else
+			trans->transmission = TRANSMISSION_MODE_AUTO;
 
 		s = s.right( s.length()-pos-1 );
 		s = s.stripWhiteSpace();
 		pos = s.find(" ");
-		if ( s.left(pos)=="1/32" ) trans->guard = GUARD_INTERVAL_1_32;
-		else if ( s.left(pos)=="1/16" ) trans->guard = GUARD_INTERVAL_1_16;
-		else if ( s.left(pos)=="1/8" ) trans->guard = GUARD_INTERVAL_1_8;
-		else if ( s.left(pos)=="1/4" ) trans->guard = GUARD_INTERVAL_1_4;
-		else trans->guard = GUARD_INTERVAL_AUTO;
+		if ( s.left(pos)=="1/32" )
+			trans->guard = GUARD_INTERVAL_1_32;
+		else if ( s.left(pos)=="1/16" )
+			trans->guard = GUARD_INTERVAL_1_16;
+		else if ( s.left(pos)=="1/8" )
+			trans->guard = GUARD_INTERVAL_1_8;
+		else if ( s.left(pos)=="1/4" )
+			trans->guard = GUARD_INTERVAL_1_4;
+		else
+			trans->guard = GUARD_INTERVAL_AUTO;
 
 		s = s.right( s.length()-pos-1 );
 		s = s.stripWhiteSpace();
 		pos = s.find(" ");
-		if ( s.left(pos)=="1" ) trans->hierarchy = HIERARCHY_1;
-		else if ( s.left(pos)=="2" ) trans->hierarchy = HIERARCHY_2;
-		else if ( s.left(pos)=="4" ) trans->hierarchy = HIERARCHY_4;
-		else if ( s.left(pos)=="NONE" ) trans->hierarchy = HIERARCHY_NONE;
-		else 	trans->hierarchy = HIERARCHY_AUTO;
+		if ( s.left(pos)=="1" )
+			trans->hierarchy = HIERARCHY_1;
+		else if ( s.left(pos)=="2" )
+			trans->hierarchy = HIERARCHY_2;
+		else if ( s.left(pos)=="4" )
+			trans->hierarchy = HIERARCHY_4;
+		else if ( s.left(pos)=="NONE" )
+			trans->hierarchy = HIERARCHY_NONE;
+		else
+			trans->hierarchy = HIERARCHY_AUTO;
 	}
 	transponders.append( trans );
 }
@@ -479,14 +546,17 @@ bool ScanDialog::getTransData()
 		QTextStream tt( &f );
 		while ( !tt.eof() ) {
 			s = tt.readLine();
-			if ( s.startsWith("#") ) continue;
-			if ( s.length()==0 ) continue;
+			if ( s.startsWith("#") )
+				continue;
+			if ( s.length()==0 )
+				continue;
 			parseTp( s, ds->dvbType, searchComb->currentText() );
 		}
 		f.close();
 		return true;
 	}
-	else return false;
+	else
+		return false;
 }
 
 
@@ -499,19 +569,22 @@ void ScanDialog::addSelected()
 	QStringList list;
 	int n = foundList->currentItem();
 
-	if ( n<0 ) return;
+	if ( n<0 )
+		return;
 
 	for ( i=0; i<(int)foundList->count(); i++ ) {
 		chan = 0;
 		r = 0;
-		if ( !foundList->isSelected( i ) ) continue;
+		if ( !foundList->isSelected( i ) )
+			continue;
 		for ( j=0; j<(int)dvbsi->channels.count(); j++ ) {
 			if ( dvbsi->channels.at(j)->name==foundList->text(i) ) {
 				chan = dvbsi->channels.at(j);
 				break;
 			}
 		}
-		if ( !chan ) continue;
+		if ( !chan )
+			continue;
 		for ( n=0; n<(int)chandesc->count(); n++ ) {
 			if ( chan->name==chandesc->at(n)->name ) {
 				r++;
@@ -519,23 +592,29 @@ void ScanDialog::addSelected()
 				break;
 			}
 		}
-		if ( r ) continue;
+		if ( r )
+			continue;
 		chan->num = chandesc->count()+1;
 		chandesc->append( new ChannelDesc( *chan ) );
 		it = new QListViewItem( channelsList, chan->name );
 		if ( chan->type==1 ) {
-			if ( chan->fta ) it->setPixmap( 0, tvcPix );
-			else it->setPixmap( 0, tvPix );
+			if ( chan->fta )
+				it->setPixmap( 0, tvcPix );
+			else
+				it->setPixmap( 0, tvPix );
 		}
 		else {
-			if ( chan->fta ) it->setPixmap( 0, racPix );
-			else it->setPixmap( 0, raPix );
+			if ( chan->fta )
+				it->setPixmap( 0, racPix );
+			else
+				it->setPixmap( 0, raPix );
 		}
 		foundList->removeItem(i);
 		dvbsi->channels.remove(j);
 		i--;
 	}
-	if ( list.count() ) KMessageBox::informationList( this, i18n("These channels already exist and were not added :"), list );
+	if ( list.count() )
+		KMessageBox::informationList( this, i18n("These channels already exist and were not added :"), list );
 }
 
 
@@ -569,18 +648,30 @@ void ScanDialog::addFiltered()
 		t++;
 		progress->setProgress( t*100/m );
 		chan = dvbsi->channels.at(i);
-		if ( !chan->completed ) continue;
-		if ( chan->name.isEmpty() ) continue;
-		if ( chan->type<1 ) continue;
-		if ( chan->type>2 ) continue;
-		if ( chan->type==1 && chan->vpid==0 ) continue;
-		if ( chan->type==1 && chan->napid==0 ) continue;
-		if ( chan->type==2 && chan->napid==0 ) continue;
-		if ( chan->type==2 && chan->vpid!=0 ) continue;
-		if ( ftaCb->isChecked() && chan->fta ) continue;
-		if ( !tvCb->isChecked() && chan->type==1 ) continue;
-		if ( !radioCb->isChecked() && chan->type==2 ) continue;
-		if ( providerCb->isChecked() && chan->provider!=providerComb->currentText() ) continue;
+		if ( !chan->completed )
+			continue;
+		if ( chan->name.isEmpty() )
+			continue;
+		if ( chan->type<1 )
+			continue;
+		if ( chan->type>2 )
+			continue;
+		if ( chan->type==1 && chan->vpid==0 )
+			continue;
+		if ( chan->type==1 && chan->napid==0 )
+			continue;
+		if ( chan->type==2 && chan->napid==0 )
+			continue;
+		if ( chan->type==2 && chan->vpid!=0 )
+			continue;
+		if ( ftaCb->isChecked() && chan->fta )
+			continue;
+		if ( !tvCb->isChecked() && chan->type==1 )
+			continue;
+		if ( !radioCb->isChecked() && chan->type==2 )
+			continue;
+		if ( providerCb->isChecked() && chan->provider!=providerComb->currentText() )
+			continue;
 		j = 0;
 		it = channelsList->firstChild();
 		while ( it!=0 ) {
@@ -591,17 +682,22 @@ void ScanDialog::addFiltered()
 			}
 			it = it->nextSibling();
 		}
-		if ( j ) continue;
+		if ( j )
+			continue;
 		chan->num = chandesc->count()+1;
 		chandesc->append( new ChannelDesc( *chan ) );
 		it = new QListViewItem( channelsList, chan->name );
 		if ( chan->type==1 ) {
-			if ( chan->fta ) it->setPixmap( 0, tvcPix );
-			else it->setPixmap( 0, tvPix );
+			if ( chan->fta )
+				it->setPixmap( 0, tvcPix );
+			else
+				it->setPixmap( 0, tvPix );
 		}
 		else {
-			if ( chan->fta ) it->setPixmap( 0, racPix );
-			else it->setPixmap( 0, raPix );
+			if ( chan->fta )
+				it->setPixmap( 0, racPix );
+			else
+				it->setPixmap( 0, raPix );
 		}
 		for ( j=0; j<(int)foundList->count(); j++ ) {
 			if ( chan->name==foundList->text(j) ) {
@@ -617,7 +713,8 @@ void ScanDialog::addFiltered()
 			}
 		}
 	}
-	if ( list.count() ) KMessageBox::informationList( this, i18n("These channels already exist and were not added :"), list );
+	if ( list.count() )
+		KMessageBox::informationList( this, i18n("These channels already exist and were not added :"), list );
 	progress->setProgress(0);
 	startBtn->setEnabled( true );
 	working( false );
@@ -645,13 +742,16 @@ void ScanDialog::siEnded( bool b )
 void ScanDialog::scan( bool b )
 {
 	if ( b ) {
-		if ( checkTimer.isActive() ) checkTimer.stop();
+		if ( checkTimer.isActive() )
+			checkTimer.stop();
 		foundList->clear();
 		nChannels = 0;
 		ntv = nradio = 0;
-		if ( ds->isTuned() ) dvbsi->go( transponders, 2 );
+		if ( ds->isTuned() )
+			dvbsi->go( transponders, 2 );
 		else {
-			if ( !getTransData() ) return;
+			if ( !getTransData() )
+				return;
 			dvbsi->go( transponders );
 		}
 		checkTimer.start( 100 );
@@ -687,7 +787,8 @@ void ScanDialog::scan( bool b )
 
 void ScanDialog::setProgress()
 {
-	if ( !dvbsi->transponders.count() ) return;
+	if ( !dvbsi->transponders.count() )
+		return;
 	progress->setProgress( dvbsi->progressTransponder*100/dvbsi->transponders.count() );
 }
 
@@ -695,8 +796,10 @@ void ScanDialog::setProgress()
 
 void ScanDialog::setLock( bool on )
 {
-	if ( on ) lock->on();
-	else lock->off();
+	if ( on )
+		lock->on();
+	else
+		lock->off();
 }
 
 
@@ -708,15 +811,23 @@ void ScanDialog::checkNewChannel()
 
 	for ( j=nChannels; j<(int)dvbsi->channels.count(); j++ ) {
 		chan = dvbsi->channels.at(j);
-		if ( chan->completed==0 ) break;
+		if ( chan->completed==0 )
+			break;
 		nChannels++;
-		if ( chan->name.isEmpty() ) continue;
-		if ( chan->type<1 ) continue;
-		if ( chan->type>2 ) continue;
-		if ( chan->type==1 && chan->vpid==0 ) continue;
-		if ( chan->type==1 && chan->napid==0 ) continue;
-		if ( chan->type==2 && chan->napid==0 ) continue;
-		if ( chan->type==2 && chan->vpid!=0 ) continue;
+		if ( chan->name.isEmpty() )
+			continue;
+		if ( chan->type<1 )
+			continue;
+		if ( chan->type>2 )
+			continue;
+		if ( chan->type==1 && chan->vpid==0 )
+			continue;
+		if ( chan->type==1 && chan->napid==0 )
+			continue;
+		if ( chan->type==2 && chan->napid==0 )
+			continue;
+		if ( chan->type==2 && chan->vpid!=0 )
+			continue;
 		addFound( chan, true );
 	}
 }
@@ -728,32 +839,43 @@ void ScanDialog::addFound( ChannelDesc *chan, bool scan )
 	int i;
 
 	if ( chan->type==1 ) {
-		if ( scan ) ntv++;
-		if ( chan->fta ) foundList->insertItem( tvcPix, chan->name );
-		else foundList->insertItem( tvPix, chan->name );
+		if ( scan )
+			ntv++;
+		if ( chan->fta )
+			foundList->insertItem( tvcPix, chan->name );
+		else
+			foundList->insertItem( tvPix, chan->name );
 	}
 	else {
-		if ( scan ) nradio++;
-		if ( chan->fta ) foundList->insertItem( racPix, chan->name );
-		else foundList->insertItem( raPix, chan->name );
+		if ( scan )
+			nradio++;
+		if ( chan->fta )
+			foundList->insertItem( racPix, chan->name );
+		else
+			foundList->insertItem( raPix, chan->name );
 	}
-	if ( scan ) progressLab->setText( QString( i18n("Found : %1 TV - %2 radio") ).arg(ntv).arg(nradio) );
-	if ( chan->provider.isEmpty() ) return;
+	if ( scan )
+		progressLab->setText( QString( i18n("Found : %1 TV - %2 radio") ).arg(ntv).arg(nradio) );
+	if ( chan->provider.isEmpty() )
+		return;
 	for ( i=0; i<providerComb->count(); i++ ) {
 		if ( chan->provider==providerComb->text(i) ) {
 			i = -1;
 			break;
 		}
 	}
-	if ( i>-1 ) providerComb->insertItem( chan->provider );
+	if ( i>-1 )
+		providerComb->insertItem( chan->provider );
 }
 
 
 
 ScanDialog::~ScanDialog()
 {
-	if ( checkTimer.isActive() ) checkTimer.stop();
-	if ( progressTimer.isActive() ) progressTimer.stop();
+	if ( checkTimer.isActive() )
+		checkTimer.stop();
+	if ( progressTimer.isActive() )
+		progressTimer.stop();
 	dvbsi->stop();
         delete dvbsi;
 
