@@ -15,11 +15,11 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
  ***************************************************************************/
 
  /*
-  * Last modified: $Date: 2005/07/21 19:40:28 $ by $Author: hftom $
+  * Last modified: $Date: 2005/09/03 09:36:40 $ by $Author: juergenk $
   */
 
 #ifndef _KAFFEINEIFACE_H_
@@ -92,11 +92,31 @@ k_dcop:
    */
   virtual bool isPlaying() = 0;
 
+  /*
+   * Is a video being played?
+   */
+  virtual bool isVideo() = 0;
+
   /*
    * Returns current track title
    */
   virtual QString title() = 0;
 
+  /*
+   * Returns current artist
+   */
+  virtual QString artist() = 0;
+
+  /*
+   * Returns current album
+   */
+  virtual QString album() = 0;
+
+  /*
+   * Return current track
+   */
+  virtual QString track() = 0;
+
   /*
    * Returns current track file (media) name
    */
