@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
  ***************************************************************************/
 
 /*
@@ -60,7 +60,7 @@ GStreamerPart::GStreamerPart(QWidget* parentWidget, const char* /*widgetName*/,
                              const QStringList& /*args*/)
 		: KMediaPart(parent, name ? name : "GStreamerPart"),
 		m_play(NULL), m_videosink(NULL), m_audiosink(NULL), m_visual(NULL), m_videoSettings(NULL), m_gstConfig(NULL),
-		m_gstReady(false), m_mute(false), m_posToolbar(NULL)
+		m_gstReady(false), m_mute(false), m_logoPath(QString::null), m_posToolbar(NULL)
 {
 	// we need an instance
 	setInstance(GStreamerPartFactory::instance());
@@ -462,8 +462,13 @@ void GStreamerPart::slotSetPosition(uint percent)
 
 void GStreamerPart::slotStop()
 {
-	m_url = m_logoPath;
-	gstPlay(m_logoPath, QString::null);
+	if (!m_logoPath.isNull())
+	{
+		m_url = m_logoPath;
+		gstPlay(m_logoPath, QString::null);
+	}
+	else
+		gst_element_set_state(m_play, GST_STATE_READY);
 }
 
 void GStreamerPart::slotVolume(int vol)
@@ -741,27 +746,30 @@ void GStreamerPart::timerEvent(QTimerEvent* tevent)
 	switch ( tevent->timerId() )
 	{
 		case TIMER_EVENT_PLAYBACK_FINISHED:
+		{
+			kdDebug() << "GStreamerPart: Playback finished" << endl;
+			if (GST_STATE (m_play) > GST_STATE_READY)
+				gst_element_set_state (m_play, GST_STATE_READY);
+			if (m_current < m_playlist.count()-1)
 			{
-			    kdDebug() << "GStreamerPart: Playback finished" << endl;
-			    if (GST_STATE (m_play) > GST_STATE_READY)
-			    gst_element_set_state (m_play, GST_STATE_READY);
-			    if (m_current < m_playlist.count()-1)
-			    {
-				    m_current ++;
-				    slotPlay();
-				    }
-				    else
-				    {
-					    if (m_url != m_logoPath)
-						    emit signalTrackFinished();
-				    }
-		    break;
+				m_current ++;
+				slotPlay();
+			}
+			else
+			{
+				if (m_url != m_logoPath)
+					emit signalTrackFinished();
+			}
+			break;
 		}
 		case TIMER_EVENT_ERROR:
 		{
 			emit setStatusBarText(i18n("Error"));
-			KMessageBox::detailedError(0, m_errorMsg, m_errorDetails);
-			emit signalPlaybackFailed();
+			if (m_url != m_logoPath)
+			{
+				KMessageBox::detailedError(0, m_errorMsg, m_errorDetails);
+				emit signalPlaybackFailed();
+			}
 			break;
 		}
 		case TIMER_EVENT_NEW_STATE:
@@ -1053,3 +1061,5 @@ void GStreamerPart::got_source(GstElement* /*play*/, GParamSpec* /*pspec*/, gpoi
 	}
 }
 
+
+
