@@ -15,11 +15,11 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
  ***************************************************************************/
 
 /*
- * Last modified: $Date: 2005/07/24 00:59:57 $ by $Author: hftom $
+ * Last modified: $Date: 2005/09/03 09:36:40 $ by $Author: juergenk $
  */
 
 #include "kaffeine_part.h"
@@ -636,7 +636,8 @@ void KaffeinePart::slotChannelInfo(const QStringList& audio, const QStringList&
 		QStringList subFiles = m_playlist[m_current].subtitleFiles();
 		QStringList subs(i18n("off"));
 		QString sub;
-		for (QStringList::ConstIterator it = subFiles.begin(); it != subFiles.end(); it++)
+		QStringList::ConstIterator end(subFiles.end());
+		for (QStringList::ConstIterator it = subFiles.begin(); it != end; ++it)
 		{
 			sub = (*it);
 			sub = sub.remove(0 , sub.findRev('/')+1);
