@@ -3,8 +3,8 @@
 		A KDE/QT API for the xine-lib. Define USE_QT_ONLY if you use QT only.
                            -------------------
     begin                : Fre Apr 18 2003
-    revision             : $Revision: 1.47 $
-    last modified        : $Date: 2005/08/06 23:28:07 $ by $Author: hftom $
+    revision             : $Revision: 1.48 $
+    last modified        : $Date: 2005/08/22 19:36:46 $ by $Author: juergenk $
     copyright            : (C) 2003-2005 by Jürgen Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -681,7 +681,7 @@ void KXineWidget::timerEvent( QTimerEvent* tevent )
 	{
 		case TIMER_EVENT_PLAYBACK_FINISHED:
 		{
-			if ( TimeShiftFilename!="" )
+			if ( !TimeShiftFilename.isEmpty() )
 			{
 				QTimer::singleShot(0, this, SLOT(slotPlayTimeShift()));
 				break;
@@ -1615,7 +1615,7 @@ void KXineWidget::dvbShowOSD()
 				xine_osd_show( dvbOSD, 0 );
 				return;
 			}
-			if ( dvbCurrentNext[1]!="" )
+			if ( !dvbCurrentNext[1].isEmpty() )
 			{
 				s = dvbCurrentNext[1];
 				pos = s.find("-");
@@ -1635,7 +1635,7 @@ void KXineWidget::dvbShowOSD()
 				xine_osd_draw_text( dvbOSD, 10+offset, y, t, DVB_TEXT_WHITE );
 				y+= 40;
 			}
-			if ( dvbCurrentNext[2]!="" )
+			if ( !dvbCurrentNext[2].isEmpty() )
 			{
 				c = dvbCurrentNext[2];
 				pos = 0;
@@ -1658,7 +1658,7 @@ void KXineWidget::dvbShowOSD()
 				}
 				y+= 40;
 			}
-			if ( dvbCurrentNext[3]!="" )
+			if ( !dvbCurrentNext[3].isEmpty() )
 			{
 				c = dvbCurrentNext[3];
 				pos = 0;
