@@ -2,8 +2,8 @@
                           xineconfig.cpp - config dialog for xine parameters
                              -------------------
     begin                : Son Mai 4 2003
-    revision             : $Revision: 1.5 $
-    last modified        : $Date: 2005/07/18 18:17:46 $ by $Author: juergenk $
+    revision             : $Revision: 1.6 $
+    last modified        : $Date: 2005/08/22 19:36:46 $ by $Author: juergenk $
     copyright            : (C) 2003-2005 by Jürgen Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -246,7 +246,8 @@ XineConfig::XineConfig(const xine_t* const xine) :
 	QVBox* xineExpertPage = NULL;
 	QString icon;
 
-	for (QStringList::ConstIterator it = cats.begin(); it != cats.end(); it++)
+	QStringList::ConstIterator end ( cats.end());
+	for (QStringList::ConstIterator it = cats.begin(); it != end; ++it)
 	{
 		//  kdDebug() << "XineConfig: add page: " << *it << endl;
 		if (*it == "audio")
