@@ -15,11 +15,11 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
  ***************************************************************************/
 
 /*
- * Last modified: $Date: 2005/08/05 15:55:20 $ by $Author: gillata $
+ * Last modified: $Date: 2005/09/03 09:36:40 $ by $Author: juergenk $
  */
 
 #include <kdebug.h>
@@ -109,7 +109,8 @@ bool PlaylistImport::kaffeine(const QString& playlist, MRL::List& mrls)
 	}
 	else
 	{
-		for (MRL::List::ConstIterator it = parser.mrls.begin(); it != parser.mrls.end(); it++)
+		MRL::List::ConstIterator end(parser.mrls.end());
+		for (MRL::List::ConstIterator it = parser.mrls.begin(); it != end; ++it)
 			mrls.append(*it);
 		return true;
 	}
@@ -184,7 +185,8 @@ bool PlaylistImport::noatun(const QString& playlist, MRL::List& mrls)
 	}
 	else
 	{
-		for (MRL::List::ConstIterator it = parser.mrls.begin(); it != parser.mrls.end(); it++)
+		MRL::List::ConstIterator end(parser.mrls.end());
+		for (MRL::List::ConstIterator it = parser.mrls.begin(); it != end; ++it)
 			mrls.append(*it);
 		return true;
 	}
@@ -310,7 +312,7 @@ bool PlaylistImport::pls(const QString& playlist, MRL::List& mrls)
 			entryCnt++;
 			continue;
 		}
-	
+
 		if (tmp.contains(regExp_NumberOfEntries)) {
 			numberOfEntries = tmp.section('=', -1).stripWhiteSpace().toUInt();
 			continue;
@@ -318,7 +320,7 @@ bool PlaylistImport::pls(const QString& playlist, MRL::List& mrls)
 	}
 
 	file.close();
-	
+
 	if (numberOfEntries != entryCnt) {
 		kdError() << "PlaylistImport: Invalid \"NumberOfEntries\" value in .pls playlist.  "
 			<< "NumberOfEntries=" << numberOfEntries << "  counted="
@@ -340,7 +342,7 @@ bool PlaylistImport::pls(const QString& playlist, MRL::List& mrls)
 	QString* titles = new QString[entryCnt];
 	QString* files = new QString[entryCnt];
 	QTime* length = new QTime[entryCnt];
-	
+
 	QStringList::const_iterator i = lines.begin(), end = lines.end();
 	for ( ; i != end; ++i) {
 		if (!inPlaylistSection && havePlaylistSection) {
@@ -464,7 +466,7 @@ bool PlaylistImport::ram(const MRL& playlist, MRL::List& mrls, QWidget* parent)
 		}
 		else
 		{
-			kdWarning() << "PlaylistImport: ram: Download via " << playlist.kurl().protocol() <<
+			kdError() << "PlaylistImport: ram: Download via " << playlist.kurl().protocol() <<
 			" protocol not supported." << endl;
 			return false;
 		}
@@ -517,7 +519,15 @@ bool PlaylistImport::asx(const QString& playlist, MRL::List& mrls)
 	if (!file.open(IO_ReadOnly)) return false;
 
 	QDomDocument doc;
-	doc.setContent(&file);
+	QString errorMsg;
+	int errorLine, errorColumn;
+	if (!doc.setContent(&file, &errorMsg, &errorLine, &errorColumn))
+	{
+		kdError() << "PlaylistImport: XML parse error: " << errorMsg
+		          << " (line: " << errorLine << ", column: " << errorColumn << ")" << endl;
+		return false;
+	}
+
 	QDomElement root = doc.documentElement();
 
 	QString url;
