@@ -2,8 +2,8 @@
                            playlist.cpp
                            -------------------
     begin                : Die Apr 22 2003
-    revision             : $Revision: 1.87 $
-    last modified        : $Date: 2005/08/05 15:55:22 $ by $Author: gillata $
+    revision             : $Revision: 1.88 $
+    last modified        : $Date: 2005/08/22 19:36:46 $ by $Author: juergenk $
     copyright            : (C) 2003-2005 by Jürgen Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -636,7 +636,8 @@ void PlayList::add(const QStringList& urlList, QListViewItem* after)
 				}
 				if (playlist)
 				{
-					for (MRL::List::ConstIterator it = mrlList.begin(); it != mrlList.end(); it++)
+					MRL::List::ConstIterator end(mrlList.end());
+					for (MRL::List::ConstIterator it = mrlList.begin(); it != end; ++it)
 						after = insertItem(after, *it);
 					continue;
 				}
@@ -650,7 +651,8 @@ void PlayList::add(const QStringList& urlList, QListViewItem* after)
 				kdDebug() << "PlayList: Try loading ram playlist\n";
 				if (PlaylistImport::ram(mrl, mrlList, parentWidget()))
 				{
-					for (MRL::List::ConstIterator it = mrlList.begin(); it != mrlList.end(); it++)
+					MRL::List::ConstIterator end(mrlList.end());
+					for (MRL::List::ConstIterator it = mrlList.begin(); it != end; ++it)
 						after = insertItem(after, *it);
 					continue;
 				}
@@ -748,8 +750,8 @@ void PlayList::add(const QStringList& urlList, QListViewItem* after)
 				//Do a case insensitive search for subs
 				QStringList dirListing = d->entryList(QDir::Files|QDir::NoSymLinks); //cache directory listing
 				bool matches = false;
-
-				for(QStringList::Iterator it = dirListing.begin(); it != dirListing.end(); ++it )
+				QStringList::Iterator end(dirListing.end());
+				for(QStringList::Iterator it = dirListing.begin(); it != end; ++it )
 				{
 					if(startsWith(*it, filename.section('.',0,-2), false)) //If filenames (without extensions) match
 					{
@@ -825,7 +827,8 @@ void PlayList::add(const QStringList& urlList, QListViewItem* after)
 
 void PlayList::add(const MRL::List& mrlList, QListViewItem* after)
 {
-	for (MRL::List::ConstIterator it = mrlList.begin(); it != mrlList.end(); it++)
+	MRL::List::ConstIterator end(mrlList.end());
+	for (MRL::List::ConstIterator it = mrlList.begin(); it != end; ++it)
 		after = insertItem(after, *it);
 	updateStatus();
 	if (m_random) createRandomList();
@@ -1120,7 +1123,8 @@ void PlayList::updateStatus()
 	if (isQueueMode())
 	{
 		QTime total;
-		for (MRL::List::ConstIterator it = m_queue.begin(); it != m_queue.end(); it++)
+		MRL::List::ConstIterator end(m_queue.end());
+		for (MRL::List::ConstIterator it = m_queue.begin(); it != end; ++it)
 			total = total.addSecs(QTime().secsTo((*it).length()));
 		status = i18n("Queue: %1 Entries, Playtime: %2").arg(m_queue.count()).arg(total.toString("h:mm:ss"));
 	}
