@@ -15,11 +15,11 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
  ***************************************************************************/
 
  /*
-  * Last modified: $Date: 2005/04/29 20:45:50 $ by $Author: hftom $
+  * Last modified: $Date: 2005/09/03 09:36:40 $ by $Author: juergenk $
   */
 
 #include "pref.h"
@@ -233,7 +233,7 @@ void KaffeinePreferences::slotOkPressed()
 void KaffeinePreferences::setShiftDir()
 {
   QString s = KFileDialog::getExistingDirectory( m_shiftDirLe->text().stripWhiteSpace() );
-  if ( s!="" ) m_shiftDirLe->setText( s );
+  if ( !s.isEmpty() ) m_shiftDirLe->setText( s );
 }
 
 void KaffeinePreferences::slotUseAlternateEncodingToggled(bool on)
